<?php
/**
 * The template for homepage posts with "Portfolio" style
 *
 * @package WordPress
 * @subpackage PLAYHOCKEY
 * @since PLAYHOCKEY 1.0
 */

playhockey_storage_set('blog_archive', true);

// Load scripts for both 'Gallery' and 'Portfolio' layouts!
wp_enqueue_script( 'classie', playhockey_get_file_url('js/theme.gallery/classie.min.js'), array(), null, true );
wp_enqueue_script( 'imagesloaded', playhockey_get_file_url('js/theme.gallery/imagesloaded.min.js'), array(), null, true );
wp_enqueue_script( 'masonry', playhockey_get_file_url('js/theme.gallery/masonry.min.js'), array(), null, true );
wp_enqueue_script( 'playhockey-gallery-script', playhockey_get_file_url('js/theme.gallery/theme.gallery.js'), array(), null, true );

get_header(); 

if (have_posts()) {

	echo get_query_var('blog_archive_start');

	$playhockey_stickies = is_home() ? get_option( 'sticky_posts' ) : false;
	$playhockey_sticky_out = is_array($playhockey_stickies) && count($playhockey_stickies) > 0 && get_query_var( 'paged' ) < 1;
	
	// Show filters
	$playhockey_cat = playhockey_get_theme_option('parent_cat');
	$playhockey_post_type = playhockey_get_theme_option('post_type');
	$playhockey_taxonomy = playhockey_get_post_type_taxonomy($playhockey_post_type);
	$playhockey_show_filters = playhockey_get_theme_option('show_filters');
	$playhockey_tabs = array();
	if (!playhockey_is_off($playhockey_show_filters)) {
		$playhockey_args = array(
			'type'			=> $playhockey_post_type,
			'child_of'		=> $playhockey_cat,
			'orderby'		=> 'name',
			'order'			=> 'ASC',
			'hide_empty'	=> 1,
			'hierarchical'	=> 0,
			'exclude'		=> '',
			'include'		=> '',
			'number'		=> '',
			'taxonomy'		=> $playhockey_taxonomy,
			'pad_counts'	=> false
		);
		$playhockey_portfolio_list = get_terms($playhockey_args);
		if (is_array($playhockey_portfolio_list) && count($playhockey_portfolio_list) > 0) {
			$playhockey_tabs[$playhockey_cat] = esc_html__('All', 'playhockey');
			foreach ($playhockey_portfolio_list as $playhockey_term) {
				if (isset($playhockey_term->term_id)) $playhockey_tabs[$playhockey_term->term_id] = $playhockey_term->name;
			}
		}
	}
	if (count($playhockey_tabs) > 0) {
		$playhockey_portfolio_filters_ajax = true;
		$playhockey_portfolio_filters_active = $playhockey_cat;
		$playhockey_portfolio_filters_id = 'portfolio_filters';
		if (!is_customize_preview())
			wp_enqueue_script('jquery-ui-tabs', false, array('jquery', 'jquery-ui-core'), null, true);
		?>
		<div class="portfolio_filters playhockey_tabs playhockey_tabs_ajax">
			<ul class="portfolio_titles playhockey_tabs_titles">
				<?php
				foreach ($playhockey_tabs as $playhockey_id=>$playhockey_title) {
					?><li><a href="<?php echo esc_url(playhockey_get_hash_link(sprintf('#%s_%s_content', $playhockey_portfolio_filters_id, $playhockey_id))); ?>" data-tab="<?php echo esc_attr($playhockey_id); ?>"><?php echo esc_html($playhockey_title); ?></a></li><?php
				}
				?>
			</ul>
			<?php
			$playhockey_ppp = playhockey_get_theme_option('posts_per_page');
			if (playhockey_is_inherit($playhockey_ppp)) $playhockey_ppp = '';
			foreach ($playhockey_tabs as $playhockey_id=>$playhockey_title) {
				$playhockey_portfolio_need_content = $playhockey_id==$playhockey_portfolio_filters_active || !$playhockey_portfolio_filters_ajax;
				?>
				<div id="<?php echo esc_attr(sprintf('%s_%s_content', $playhockey_portfolio_filters_id, $playhockey_id)); ?>"
					class="portfolio_content playhockey_tabs_content"
					data-blog-template="<?php echo esc_attr(playhockey_storage_get('blog_template')); ?>"
					data-blog-style="<?php echo esc_attr(playhockey_get_theme_option('blog_style')); ?>"
					data-posts-per-page="<?php echo esc_attr($playhockey_ppp); ?>"
					data-post-type="<?php echo esc_attr($playhockey_post_type); ?>"
					data-taxonomy="<?php echo esc_attr($playhockey_taxonomy); ?>"
					data-cat="<?php echo esc_attr($playhockey_id); ?>"
					data-parent-cat="<?php echo esc_attr($playhockey_cat); ?>"
					data-need-content="<?php echo (false===$playhockey_portfolio_need_content ? 'true' : 'false'); ?>"
				>
					<?php
					if ($playhockey_portfolio_need_content) 
						playhockey_show_portfolio_posts(array(
							'cat' => $playhockey_id,
							'parent_cat' => $playhockey_cat,
							'taxonomy' => $playhockey_taxonomy,
							'post_type' => $playhockey_post_type,
							'page' => 1,
							'sticky' => $playhockey_sticky_out
							)
						);
					?>
				</div>
				<?php
			}
			?>
		</div>
		<?php
	} else {
		playhockey_show_portfolio_posts(array(
			'cat' => $playhockey_cat,
			'parent_cat' => $playhockey_cat,
			'taxonomy' => $playhockey_taxonomy,
			'post_type' => $playhockey_post_type,
			'page' => 1,
			'sticky' => $playhockey_sticky_out
			)
		);
	}

	echo get_query_var('blog_archive_end');

} else {

	if ( is_search() )
		get_template_part( 'content', 'none-search' );
	else
		get_template_part( 'content', 'none-archive' );

}

get_footer();
?>