<?php
/* Mail Chimp support functions
------------------------------------------------------------------------------- */

// Theme init priorities:
// 9 - register other filters (for installer, etc.)
if (!function_exists('playhockey_mailchimp_theme_setup9')) {
	add_action( 'after_setup_theme', 'playhockey_mailchimp_theme_setup9', 9 );
	function playhockey_mailchimp_theme_setup9() {
		if (playhockey_exists_mailchimp()) {
			add_action( 'wp_enqueue_scripts',							'playhockey_mailchimp_frontend_scripts', 1100 );
			add_filter( 'playhockey_filter_merge_styles',					'playhockey_mailchimp_merge_styles');
			add_filter( 'playhockey_filter_get_css',						'playhockey_mailchimp_get_css', 10, 4);
		}
		if (is_admin()) {
			add_filter( 'playhockey_filter_tgmpa_required_plugins',		'playhockey_mailchimp_tgmpa_required_plugins' );
		}
	}
}

// Check if plugin installed and activated
if ( !function_exists( 'playhockey_exists_mailchimp' ) ) {
	function playhockey_exists_mailchimp() {
		return function_exists('__mc4wp_load_plugin') || defined('MC4WP_VERSION');
	}
}

// Filter to add in the required plugins list
if ( !function_exists( 'playhockey_mailchimp_tgmpa_required_plugins' ) ) {
	
	function playhockey_mailchimp_tgmpa_required_plugins($list=array()) {
		if (in_array('mailchimp-for-wp', playhockey_storage_get('required_plugins')))
			$list[] = array(
				'name' 		=> esc_html__('MailChimp for WP', 'playhockey'),
				'slug' 		=> 'mailchimp-for-wp',
				'required' 	=> false
			);
		return $list;
	}
}



// Custom styles and scripts
//------------------------------------------------------------------------

// Enqueue custom styles
if ( !function_exists( 'playhockey_mailchimp_frontend_scripts' ) ) {
	
	function playhockey_mailchimp_frontend_scripts() {
		if (playhockey_exists_mailchimp()) {
			if (playhockey_is_on(playhockey_get_theme_option('debug_mode')) && file_exists(playhockey_get_file_dir('plugins/mailchimp-for-wp/mailchimp-for-wp.css')))
				wp_enqueue_style( 'playhockey-mailchimp-for-wp',  playhockey_get_file_url('plugins/mailchimp-for-wp/mailchimp-for-wp.css'), array(), null );
		}
	}
}
	
// Merge custom styles
if ( !function_exists( 'playhockey_mailchimp_merge_styles' ) ) {
	
	function playhockey_mailchimp_merge_styles($list) {
		$list[] = 'plugins/mailchimp-for-wp/mailchimp-for-wp.css';
		return $list;
	}
}

// Add css styles into global CSS stylesheet
if (!function_exists('playhockey_mailchimp_get_css')) {
	
	function playhockey_mailchimp_get_css($css, $colors, $fonts, $scheme='') {
		
		if (isset($css['fonts']) && $fonts) {
			$css['fonts'] .= <<<CSS

CSS;
		}
		
		if (isset($css['colors']) && $colors) {
			$css['colors'] .= <<<CSS

.mc4wp-form input[type="email"] {
	background-color: {$colors['alter_dark']};
	border-color: {$colors['alter_dark']};
	color: {$colors['bg_color']};
}
.mc4wp-form input[type="submit"] {
	background-color: {$colors['alter_link']};
	color: {$colors['inverse_text']};
}
.mc4wp-form input[type="submit"]:hover {
	background-color: {$colors['alter_dark']};
	color: {$colors['alter_bg_color']};
}

CSS;
		}

		return $css;
	}
}
?>