<?php
/* Tribe Events Calendar support functions
------------------------------------------------------------------------------- */

// Theme init priorities:
// 1 - register filters, that add/remove lists items for the Theme Options
if (!function_exists('playhockey_tribe_events_theme_setup1')) {
	add_action( 'after_setup_theme', 'playhockey_tribe_events_theme_setup1', 1 );
	function playhockey_tribe_events_theme_setup1() {
		add_filter( 'playhockey_filter_list_sidebars', 'playhockey_tribe_events_list_sidebars' );
	}
}

// Theme init priorities:
// 3 - add/remove Theme Options elements
if (!function_exists('playhockey_tribe_events_theme_setup3')) {
	add_action( 'after_setup_theme', 'playhockey_tribe_events_theme_setup3', 3 );
	function playhockey_tribe_events_theme_setup3() {
		if (playhockey_exists_tribe_events()) {
			playhockey_storage_merge_array('options', '', array(
				// Section 'Tribe Events' - settings for show pages
				'events' => array(
					"title" => esc_html__('Events', 'playhockey'),
					"desc" => wp_kses_data( __('Select parameters to display the events pages', 'playhockey') ),
					"type" => "section"
					),
				'expand_content_events' => array(
					"title" => esc_html__('Expand content', 'playhockey'),
					"desc" => wp_kses_data( __('Expand the content width if the sidebar is hidden', 'playhockey') ),
					"refresh" => false,
					"std" => 1,
					"type" => "checkbox"
					),
				'header_widgets_events' => array(
					"title" => esc_html__('Header widgets', 'playhockey'),
					"desc" => wp_kses_data( __('Select set of widgets to show in the header on the events pages', 'playhockey') ),
					"std" => 'hide',
					"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'playhockey')), playhockey_get_list_sidebars()),
					"type" => "select"
					),
				'sidebar_widgets_events' => array(
					"title" => esc_html__('Sidebar widgets', 'playhockey'),
					"desc" => wp_kses_data( __('Select sidebar to show on the events pages', 'playhockey') ),
					"std" => 'tribe_events_widgets',
					"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'playhockey')), playhockey_get_list_sidebars()),
					"type" => "select"
					),
				'sidebar_position_events' => array(
					"title" => esc_html__('Sidebar position', 'playhockey'),
					"desc" => wp_kses_data( __('Select position to show sidebar on the events pages', 'playhockey') ),
					"refresh" => false,
					"std" => 'left',
					"options" => playhockey_get_list_sidebars_positions(),
					"type" => "select"
					),
				'widgets_above_page_events' => array(
					"title" => esc_html__('Widgets above the page', 'playhockey'),
					"desc" => wp_kses_data( __('Select widgets to show above page (content and sidebar)', 'playhockey') ),
					"std" => 'hide',
					"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'playhockey')), playhockey_get_list_sidebars()),
					"type" => "select"
					),
				'widgets_above_content_events' => array(
					"title" => esc_html__('Widgets above the content', 'playhockey'),
					"desc" => wp_kses_data( __('Select widgets to show at the beginning of the content area', 'playhockey') ),
					"std" => 'hide',
					"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'playhockey')), playhockey_get_list_sidebars()),
					"type" => "select"
					),
				'widgets_below_content_events' => array(
					"title" => esc_html__('Widgets below the content', 'playhockey'),
					"desc" => wp_kses_data( __('Select widgets to show at the ending of the content area', 'playhockey') ),
					"std" => 'hide',
					"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'playhockey')), playhockey_get_list_sidebars()),
					"type" => "select"
					),
				'widgets_below_page_events' => array(
					"title" => esc_html__('Widgets below the page', 'playhockey'),
					"desc" => wp_kses_data( __('Select widgets to show below the page (content and sidebar)', 'playhockey') ),
					"std" => 'hide',
					"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'playhockey')), playhockey_get_list_sidebars()),
					"type" => "select"
					),
				'footer_scheme_events' => array(
					"title" => esc_html__('Footer Color Scheme', 'playhockey'),
					"desc" => wp_kses_data( __('Select color scheme to decorate footer area', 'playhockey') ),
					"std" => 'dark',
					"options" => playhockey_get_list_schemes(true),
					"type" => "select"
					),
				'footer_widgets_events' => array(
					"title" => esc_html__('Footer widgets', 'playhockey'),
					"desc" => wp_kses_data( __('Select set of widgets to show in the footer', 'playhockey') ),
					"std" => 'footer_widgets',
					"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'playhockey')), playhockey_get_list_sidebars()),
					"type" => "select"
					),
				'footer_columns_events' => array(
					"title" => esc_html__('Footer columns', 'playhockey'),
					"desc" => wp_kses_data( __('Select number columns to show widgets in the footer. If 0 - autodetect by the widgets count', 'playhockey') ),
					"dependency" => array(
						'footer_widgets_events' => array('^hide')
					),
					"std" => 0,
					"options" => playhockey_get_list_range(0,6),
					"type" => "select"
					),
				'footer_wide_events' => array(
					"title" => esc_html__('Footer fullwide', 'playhockey'),
					"desc" => wp_kses_data( __('Do you want to stretch the footer to the entire window width?', 'playhockey') ),
					"std" => 0,
					"type" => "checkbox"
					)
				)
			);
		}
	}
}

// Theme init priorities:
// 9 - register other filters (for installer, etc.)
if (!function_exists('playhockey_tribe_events_theme_setup9')) {
	add_action( 'after_setup_theme', 'playhockey_tribe_events_theme_setup9', 9 );
	function playhockey_tribe_events_theme_setup9() {
		
		if (playhockey_exists_tribe_events()) {
			add_action( 'wp_enqueue_scripts', 								'playhockey_tribe_events_frontend_scripts', 1100 );
			add_filter( 'playhockey_filter_merge_styles',						'playhockey_tribe_events_merge_styles' );
			add_filter( 'playhockey_filter_get_css',							'playhockey_tribe_events_get_css', 10, 4 );
			add_filter( 'playhockey_filter_post_type_taxonomy',				'playhockey_tribe_events_post_type_taxonomy', 10, 2 );
			if (!is_admin()) {
				add_filter( 'playhockey_filter_detect_blog_mode',				'playhockey_tribe_events_detect_blog_mode' );
				add_filter( 'playhockey_filter_get_post_categories', 			'playhockey_tribe_events_get_post_categories');
				add_filter( 'playhockey_filter_get_post_date',		 			'playhockey_tribe_events_get_post_date');
			} else {
				add_action( 'admin_enqueue_scripts',						'playhockey_tribe_events_admin_scripts' );
			}
		}
		if (is_admin()) {
			add_filter( 'playhockey_filter_tgmpa_required_plugins',			'playhockey_tribe_events_tgmpa_required_plugins' );
		}

	}
}



// Check if Tribe Events is installed and activated
if ( !function_exists( 'playhockey_exists_tribe_events' ) ) {
	function playhockey_exists_tribe_events() {
		return class_exists( 'Tribe__Events__Main' );
	}
}

// Return true, if current page is any tribe_events page
if ( !function_exists( 'playhockey_is_tribe_events_page' ) ) {
	function playhockey_is_tribe_events_page() {
		$rez = false;
		if (playhockey_exists_tribe_events())
			if (!is_search()) $rez = tribe_is_event() || tribe_is_event_query() || tribe_is_event_category() || tribe_is_event_venue() || tribe_is_event_organizer();
		return $rez;
	}
}

// Detect current blog mode
if ( !function_exists( 'playhockey_tribe_events_detect_blog_mode' ) ) {
	
	function playhockey_tribe_events_detect_blog_mode($mode='') {
		if (playhockey_is_tribe_events_page())
			$mode = 'events';
		return $mode;
	}
}

// Return taxonomy for current post type
if ( !function_exists( 'playhockey_tribe_events_post_type_taxonomy' ) ) {
	
	function playhockey_tribe_events_post_type_taxonomy($tax='', $post_type='') {
		if (playhockey_exists_tribe_events() && $post_type == Tribe__Events__Main::POSTTYPE)
			$tax = Tribe__Events__Main::TAXONOMY;
		return $tax;
	}
}

// Show categories of the current event
if ( !function_exists( 'playhockey_tribe_events_get_post_categories' ) ) {
	
	function playhockey_tribe_events_get_post_categories($cats='') {
		if (get_post_type()==Tribe__Events__Main::POSTTYPE) {
			$cats = playhockey_get_post_terms(', ', get_the_ID(), Tribe__Events__Main::TAXONOMY);
		}
		return $cats;
	}
}

// Return date of the current event
if ( !function_exists( 'playhockey_tribe_events_get_post_date' ) ) {
	
	function playhockey_tribe_events_get_post_date($dt='') {
		if (get_post_type()==Tribe__Events__Main::POSTTYPE) {
			$dt = tribe_get_start_date(null, true, 'Y-m-d');
			$dt = sprintf($dt < date_i18n('Y-m-d')
								? esc_html__('Started on %s', 'playhockey')
								: esc_html__('Starting %s', 'playhockey'),
                date_i18n(get_option('date_format'), strtotime($dt)));
		}
		return $dt;
	}
}
	
// Enqueue Tribe Events admin scripts and styles
if ( !function_exists( 'playhockey_tribe_events_admin_scripts' ) ) {
	
	function playhockey_tribe_events_admin_scripts() {
		wp_deregister_style('tribe-jquery-ui-theme');
	}
}

// Enqueue Tribe Events custom scripts and styles
if ( !function_exists( 'playhockey_tribe_events_frontend_scripts' ) ) {
	
	function playhockey_tribe_events_frontend_scripts() {
		if (playhockey_is_tribe_events_page()) {
			wp_deregister_style('tribe-events-custom-jquery-styles');
			if (playhockey_is_on(playhockey_get_theme_option('debug_mode')) && file_exists(playhockey_get_file_dir('plugins/the-events-calendar/the-events-calendar.css')))
				wp_enqueue_style( 'playhockey-the-events-calendar',  playhockey_get_file_url('plugins/the-events-calendar/the-events-calendar.css'), array(), null );
		}
	}
}

// Merge custom styles
if ( !function_exists( 'playhockey_tribe_events_merge_styles' ) ) {
	
	function playhockey_tribe_events_merge_styles($list) {
		$list[] = 'plugins/the-events-calendar/the-events-calendar.css';
		return $list;
	}
}

// Filter to add in the required plugins list
if ( !function_exists( 'playhockey_tribe_events_tgmpa_required_plugins' ) ) {
	
	function playhockey_tribe_events_tgmpa_required_plugins($list=array()) {
		if (in_array('the-events-calendar', playhockey_storage_get('required_plugins')))
			$list[] = array(
					'name' 		=> esc_html__('Tribe Events Calendar', 'playhockey'),
					'slug' 		=> 'the-events-calendar',
					'required' 	=> false
				);
		return $list;
	}
}



// Add Tribe Events specific items into lists
//------------------------------------------------------------------------

// Add sidebar
if ( !function_exists( 'playhockey_tribe_events_list_sidebars' ) ) {
	
	function playhockey_tribe_events_list_sidebars($list=array()) {
		$list['tribe_events_widgets'] = array(
											'name' => esc_html__('Tribe Events Widgets', 'playhockey'),
											'description' => esc_html__('Widgets to be shown on the Tribe Events pages', 'playhockey')
											);
		return $list;
	}
}



// Add Tribe Events specific styles into color scheme
//------------------------------------------------------------------------

// Add styles into CSS
if ( !function_exists( 'playhockey_tribe_events_get_css' ) ) {
	
	function playhockey_tribe_events_get_css($css, $colors, $fonts, $scheme='') {
		if (isset($css['fonts']) && $fonts) {
			$css['fonts'] .= <<<CSS
			
.tribe-events-list .tribe-events-list-event-title {
	{$fonts['h3_font-family']}
}



.tribe-events-calendar-month__header-column-title.tribe-common-b3,
.tribe-common .tribe-common-b3,
.tribe-events-c-subscribe-dropdown .tribe-events-c-subscribe-dropdown__button-text,
.tribe-events .tribe-events-c-ical__link,
.tribe-common .tribe-common-c-btn-border, 
.tribe-common a.tribe-common-c-btn-border,
body .tribe-events .tribe-events-c-top-bar__datepicker-button,
.tribe-common .tribe-common-c-btn,
.tribe-events .tribe-events-c-view-selector__list-item-text,

.tribe-events-list .tribe-events-list-separator-month,
.tribe-events-calendar thead th,
.tribe-events-schedule, .tribe-events-schedule h2,
.tribe-events-read-more,

.tribe-common .tribe-common-h1, .tribe-common .tribe-common-h2,
.tribe-common .tribe-common-h3, .tribe-common .tribe-common-h4,
.tribe-common .tribe-common-h5, .tribe-common .tribe-common-h6,
.tribe-common .tribe-common-h7, .tribe-common .tribe-common-h8,
#tribe-events .tribe-events-button, .tribe-events-button, .tribe-events-cal-links a, .tribe-events-sub-nav li a,
#tribe-bar-form button, #tribe-bar-form a {
	{$fonts['h5_font-family']}
}
#tribe-bar-form input, #tribe-events-content.tribe-events-month,
#tribe-events-content .tribe-events-calendar div[id*="tribe-events-event-"] h3.tribe-events-month-event-title,
#tribe-mobile-container .type-tribe_events,
.tribe-events-list-widget ol li .tribe-event-title,


.tribe-events .datepicker .day, .tribe-events .datepicker .dow,
.tribe-events .datepicker .datepicker-switch,


.tribe-events-content ol, .tribe-events-content p, .tribe-events-content ul,
.tribe-events-meta-group,

.tribe-common .tribe-common-b2,
.tribe-events .tribe-events-calendar-list__event-date-tag-weekday,
.tribe-events .datepicker .month, .tribe-events .datepicker .year,
.tribe-common--breakpoint-medium.tribe-common .tribe-common-form-control-text__input, 
.tribe-common .tribe-common-form-control-text__input  {
	{$fonts['p_font-family']}
}
.tribe-events-loop .tribe-event-schedule-details,
.single-tribe_events #tribe-events-content .tribe-events-event-meta dt,
#tribe-mobile-container .type-tribe_events .tribe-event-date-start {
	{$fonts['info_font-family']};
}

.tribe-events-calendar-list__event-datetime,
.tribe-events-calendar-day__event-datetime,
.tribe-events .tribe-events-calendar-month__calendar-event-tooltip-datetime {
	{$fonts['info_font-family']}
	{$fonts['info_font-size']}
	{$fonts['info_font-weight']}
	{$fonts['info_font-style']}
	{$fonts['info_line-height']}
	{$fonts['info_text-decoration']}
	{$fonts['info_text-transform']}
	{$fonts['info_letter-spacing']}
}

.tribe-common-c-btn.tribe-events-c-search__button,
.tribe-common .tribe-common-c-btn-border-small, 
.tribe-common a.tribe-common-c-btn-border-small,
.tribe-common .tribe-events-c-ical__link {
	{$fonts['button_font-family']}
	{$fonts['button_font-size']}
	{$fonts['button_font-weight']}
	{$fonts['button_font-style']}
	{$fonts['button_line-height']}
	{$fonts['button_text-decoration']}
	{$fonts['button_text-transform']}
	{$fonts['button_letter-spacing']}
}


CSS;
		}

		if (isset($css['colors']) && $colors) {
			$css['colors'] .= <<<CSS

/* Buttons */
.tribe-events-c-subscribe-dropdown .tribe-events-c-subscribe-dropdown__button-text,
.tribe-common .tribe-events-c-ical__link,
.tribe-common button:not(.tribe-events-c-top-bar__datepicker-button),
#tribe-bar-form .tribe-bar-submit input[type="submit"],
#tribe-bar-form.tribe-bar-mini .tribe-bar-submit input[type="submit"],
#tribe-events .tribe-events-button,
.tribe-events-button,
.tribe-events-cal-links a,
.tribe-events-sub-nav li a {
	color: {$colors['inverse_text']};
	background-color: {$colors['text_link']};
}
#tribe-bar-form .tribe-bar-submit input[type="submit"]:hover,
#tribe-bar-form .tribe-bar-submit input[type="submit"]:focus,
#tribe-bar-form.tribe-bar-mini .tribe-bar-submit input[type="submit"]:focus,
#tribe-bar-form.tribe-bar-mini .tribe-bar-submit input[type="submit"]:focus,
#tribe-events .tribe-events-button:hover,
.tribe-events-button:hover,
.tribe-events-cal-links a:hover,
.tribe-events-sub-nav li a:hover,
.tribe-events-c-subscribe-dropdown .tribe-events-c-subscribe-dropdown__button-text:hover,
 .tribe-common .tribe-events-c-ical__link:hover,
.tribe-common button:hover{
	color: {$colors['bg_color']};
	background-color: {$colors['text_dark']};
}

.tribe-events .datepicker .month.active, .scheme_default .tribe-events .datepicker .month.active.focused,
.tribe-common .tribe-events-header__events-bar button:before,
.tribe-events .tribe-events-calendar-month__mobile-events-icon--event,
.tribe-events .tribe-events-calendar-month__multiday-event-bar-inner,
.tribe-common .tribe-events-view-loader__dots .tribe-common-c-loader__dot {   
	background-color: {$colors['text_link']};
}

.tribe-events .tribe-events-calendar-month__multiday-event-bar-title{
    color: {$colors['bg_color']};
}

.tribe-common button.tribe-events-c-top-bar__datepicker-button:hover,
.tribe-events .tribe-events-calendar-month__multiday-event-bar-title:hover,
.tribe-events .tribe-events-calendar-month__day--current .tribe-events-calendar-month__day-date, 
.tribe-events .tribe-events-calendar-month__day--current .tribe-events-calendar-month__day-date-link {
    color: {$colors['text_link']};
}

/* Filters bar */
#tribe-bar-form {
	color: {$colors['text_dark']};
}
#tribe-bar-form input[type="text"] {
	color: {$colors['text_dark']};
	border-color: {$colors['text_dark']};
}
#tribe-bar-views li.tribe-bar-views-option a,
#tribe-bar-views .tribe-bar-views-list .tribe-bar-views-option.tribe-bar-active a {
	color: {$colors['inverse_text']};
	background: {$colors['text_link']};
}
#tribe-bar-views li.tribe-bar-views-option a:hover,
#tribe-bar-views .tribe-bar-views-list .tribe-bar-views-option.tribe-bar-active a:hover {
	color: {$colors['bg_color']};
	background: {$colors['text_dark']};
}
.tribe-events-c-top-bar__datepicker-time {
	color: {$colors['text_link']};
}
.datepicker thead tr:first-child th:hover, .datepicker tfoot tr th:hover {
	color: {$colors['text_link']};
	background: {$colors['text_dark']};
}
.tribe-events-c-top-bar__datepicker-desktop {
	color: {$colors['text_link']};
}
.tribe-events-c-top-bar__datepicker-desktop:hover,
.tribe-events-c-top-bar__datepicker-desktop:focus{
	color: {$colors['text_hover']};
}

.tribe-events .datepicker .day.active {
	background: {$colors['text_link']} !important;
}

.tribe-events .datepicker .day.active, .tribe-events .datepicker .day.active.focused, 
.tribe-events .datepicker .day.active:focus, .tribe-events .datepicker .day.active:hover, 
.tribe-events .datepicker .month.active, .tribe-events .datepicker .month.active.focused, 
.tribe-events .datepicker .month.active:focus, .tribe-events .datepicker .month.active:hover, 
.tribe-events .datepicker .year.active, .tribe-events .datepicker .year.active.focused, 
.tribe-events .datepicker .year.active:focus, .tribe-events .datepicker .year.active:hover,

.tribe-events .datepicker .day.focused, .tribe-events .datepicker .day:focus, 
.tribe-events .datepicker .day:hover, .tribe-events .datepicker .month.focused, 
.tribe-events .datepicker .month:focus, .tribe-events .datepicker .month:hover, 
.tribe-events .datepicker .year.focused, .tribe-events .datepicker .year:focus, 
.tribe-events .datepicker .year:hover {
	background: {$colors['text_link']} !important;
	color: {$colors['inverse_text']};
}

.tribe-events .tribe-events-c-messages__message-list-item-link{
	color: {$colors['text_link']};
}

.tribe-events .tribe-events-c-messages__message-list-item-link:hover{
	color: {$colors['text_hover']};
}



/* Content */
.tribe-events-calendar thead th {
	color: {$colors['bg_color']};
	background: {$colors['text_dark']} !important;
	border-color: {$colors['text_dark']} !important;
}
.tribe-events-calendar thead th + th:before {
	background: {$colors['bg_color']};
}
#tribe-events-content .tribe-events-calendar td {
	border-color: {$colors['bd_color']} !important;
}
.tribe-events-calendar td div[id*="tribe-events-daynum-"],
.tribe-events-calendar td div[id*="tribe-events-daynum-"] > a {
	color: {$colors['text_dark']};
}
.tribe-events-calendar td.tribe-events-othermonth {
	color: {$colors['alter_light']};
	background: {$colors['alter_bg_color']} !important;
}
.tribe-events-calendar td.tribe-events-othermonth div[id*="tribe-events-daynum-"],
.tribe-events-calendar td.tribe-events-othermonth div[id*="tribe-events-daynum-"] > a {
	color: {$colors['alter_light']};
}
.tribe-events-calendar td.tribe-events-past div[id*="tribe-events-daynum-"], .tribe-events-calendar td.tribe-events-past div[id*="tribe-events-daynum-"] > a {
	color: {$colors['text_light']};
}
.tribe-events-calendar td.tribe-events-present div[id*="tribe-events-daynum-"],
.tribe-events-calendar td.tribe-events-present div[id*="tribe-events-daynum-"] > a {
	color: {$colors['text_link']};
}
.tribe-events-calendar td.tribe-events-present:before {
	border-color: {$colors['text_link']};
}
.tribe-events-calendar .tribe-events-has-events:after {
	background-color: {$colors['text']};
}
.tribe-events-calendar .mobile-active.tribe-events-has-events:after {
	background-color: {$colors['bg_color']};
}
#tribe-events-content .tribe-events-calendar td,
#tribe-events-content .tribe-events-calendar div[id*="tribe-events-event-"] h3.tribe-events-month-event-title a {
	color: {$colors['text_dark']};
}
#tribe-events-content .tribe-events-calendar div[id*="tribe-events-event-"] h3.tribe-events-month-event-title a:hover {
	color: {$colors['text_link']};
}
#tribe-events-content .tribe-events-calendar td.mobile-active,
#tribe-events-content .tribe-events-calendar td.mobile-active:hover {
	color: {$colors['inverse_text']};
	background-color: {$colors['text_link']};
}
#tribe-events-content .tribe-events-calendar td.mobile-active div[id*="tribe-events-daynum-"] {
	color: {$colors['bg_color']};
	background-color: {$colors['text_dark']};
}
#tribe-events-content .tribe-events-calendar td.tribe-events-othermonth.mobile-active div[id*="tribe-events-daynum-"] a,
.tribe-events-calendar .mobile-active div[id*="tribe-events-daynum-"] a {
	background-color: transparent;
	color: {$colors['bg_color']};
}
.tribe-events-content ol, .tribe-events-content p, .tribe-events-content ul {
	color: {$colors['text']};
}
.tribe-events .tribe-events-calendar-month__day-cell--selected .tribe-events-calendar-month__day-date {
	color: {$colors['text_dark']};
}


/* Tooltip */
.recurring-info-tooltip,
.tribe-events-calendar .tribe-events-tooltip,
.tribe-events-week .tribe-events-tooltip,
.tribe-events-tooltip .tribe-events-arrow {
	color: {$colors['alter_text']};
	background: {$colors['alter_bg_color']};
}
#tribe-events-content .tribe-events-tooltip h4 { 
	color: {$colors['text_link']};
	background: {$colors['text_dark']};
}
.tribe-events-tooltip .tribe-event-duration {
	color: {$colors['inverse_light']};
}
.tribe-events .tribe-events-calendar-month__calendar-event-tooltip-datetime {
	color: {$colors['text_link']};
}

/* Events list */
.tribe-events-list-separator-month {
	color: {$colors['text_dark']};
}
.tribe-events-list-separator-month:after {
	border-color: {$colors['bd_color']};
}
.tribe-events-list .type-tribe_events + .type-tribe_events {
	border-color: {$colors['bd_color']};
}
.tribe-events-list .tribe-events-event-cost span {
	color: {$colors['inverse_text']};
	border-color: {$colors['text_dark']};
	background: {$colors['text_dark']};
}
.tribe-mobile .tribe-events-loop .tribe-events-event-meta {
	color: {$colors['alter_text']};
	border-color: {$colors['alter_bd_color']};
	background-color: {$colors['alter_bg_color']};
}
.tribe-mobile .tribe-events-loop .tribe-events-event-meta a {
	color: {$colors['alter_link']};
}
.tribe-mobile .tribe-events-loop .tribe-events-event-meta a:hover {
	color: {$colors['alter_hover']};
}
.tribe-mobile .tribe-events-list .tribe-events-venue-details {
	border-color: {$colors['alter_bd_color']};
}

.tribe-common .tribe-events-calendar-day__event-venue,
.tribe-common .tribe-events-calendar-list__event-venue,
.tribe-events-calendar-list__event-datetime,
.tribe-events-calendar-day__event-datetime {
	color: {$colors['text_link']};
}

/* Events day */
.tribe-events-day .tribe-events-day-time-slot h5 {
	color: {$colors['inverse_text']};
	background: {$colors['text_dark']};
}

/* Single Event */
.single-tribe_events .tribe-events-single-section {
	border-color: {$colors['bd_color']};
}
.single-tribe_events .tribe-events-venue-map {
	color: {$colors['alter_text']};
	border-color: {$colors['alter_bd_hover']};
}
.single-tribe_events .tribe-events-schedule .tribe-events-cost {
	color: {$colors['text_dark']};
}
.single-tribe_events #tribe-events-content .tribe-events-event-meta dt {
	color: {$colors['text_link']};
}
.single-tribe_events .tribe-events-single .tribe-events-event-meta {
	color: {$colors['text']};
}
.single-tribe_events .tribe-events-sub-nav li a,
.single-tribe_events .tribe-events-sub-nav li a:hover{
	color: {$colors['inverse_text']};
}

.tribe-events .tribe-events-c-view-selector__list-item-link,
.tribe-events .tribe-events-c-messages__message-list,
.tribe-events .tribe-events-calendar-month__day-date-daynum,
.tribe-events .tribe-events-calendar-list__month-separator time,
.tribe-events-meta-group .tribe-events-single-section-title,
.tribe-events .tribe-events-c-nav__next, 
.tribe-events .tribe-events-c-nav__prev,
.tribe-events .tribe-events-calendar-month-mobile-events__mobile-event-title-link,
.tribe-events .tribe-events-calendar-day__type-separator span,
.tribe-events .tribe-events-calendar-month__day-date-link,
.tribe-events .tribe-events-calendar-list__event-date-tag-datetime span,
.tribe-events .datepicker .month, 
.tribe-events .datepicker .year,
.tribe-events .datepicker .datepicker-switch,
.tribe-events .datepicker .day, 
.tribe-events .datepicker .dow,
.tribe-common .tribe-common-anchor-thin,
.tribe-events .tribe-events-calendar-day__event-title-link,
.tribe-events .tribe-events-calendar-list__event-title-link {
	color: {$colors['text_dark']};
}

.tribe-events-event-meta a{
	color: {$colors['text_link']};
}

.tribe-events-event-meta a:focus, .tribe-events-event-meta a:hover,
.tribe-events .tribe-events-c-view-selector__list-item-link:hover{
	color: {$colors['text_hover']};
}

.tribe-events .tribe-events-c-nav__prev-icon-svg path,
.tribe-events .tribe-events-c-nav__next-icon-svg path{
	fill: {$colors['text_dark']};
}

.tribe-events .tribe-events-c-nav__next:hover, 
.tribe-events .tribe-events-c-nav__prev:hover,
.tribe-events .tribe-events-c-nav__next:focus, 
.tribe-events .tribe-events-c-nav__next:hover, 
.tribe-events .tribe-events-c-nav__prev:focus, 
.tribe-events .tribe-events-c-nav__prev:hover,
.tribe-events .tribe-events-calendar-month-mobile-events__mobile-event-title-link:hover,
.tribe-events .tribe-events-calendar-month__day--current .tribe-events-calendar-month__day-date-daynum,
.tribe-common .tribe-common-anchor-thin:hover,
.tribe-events .tribe-events-calendar-day__event-title-link:hover,
.tribe-events .tribe-events-calendar-list__event-title-link :hover {
	color: {$colors['text_link']};
}

.tribe-events .tribe-events-c-nav__prev:hover path,
.tribe-events .tribe-events-c-nav__next:hover path{
	fill: {$colors['text_link']};
}

.tribe-events .tribe-events-calendar-month__calendar-event-tooltip-description,
.tribe-common .tribe-events-calendar-day__event-description,
.tribe-common .tribe-events-calendar-list__event-description{
	color: {$colors['text']};
}

.tribe-events .datepicker .past{
	color: {$colors['text']};
}


CSS;
		}
		
		return $css;
	}
}
?>