<?php
/**
 * Default Theme Options and Internal Theme Settings
 *
 * @package WordPress
 * @subpackage PLAYHOCKEY
 * @since PLAYHOCKEY 1.0
 */

// -----------------------------------------------------------------
// -- ONLY FOR PROGRAMMERS, NOT FOR CUSTOMER
// -- Internal theme settings
// -----------------------------------------------------------------
playhockey_storage_set('settings', array(
	
	'custom_sidebars'			=> 8,							// How many custom sidebars will be registered (in addition to theme preset sidebars): 0 - 10

	'ajax_views_counter'		=> true,						// Use AJAX for increment posts counter (if cache plugins used) 
																// or increment posts counter then loading page (without cache plugin)
	'disable_jquery_ui'			=> false,						// Prevent loading custom jQuery UI libraries in the third-party plugins

	'max_load_fonts'			=> 3,							// Max fonts number to load from Google fonts or from uploaded fonts

	'use_mediaelements'			=> true,						// Load script "Media Elements" to play video and audio

	'max_excerpt_length'		=> 60,							// Max words number for the excerpt in the blog style 'Excerpt'.
																// For style 'Classic' - get half from this value
	'message_maxlength'			=> 1000							// Max length of the message from contact form
	
));



// -----------------------------------------------------------------
// -- Theme fonts (Google and/or custom fonts)
// -----------------------------------------------------------------

// Fonts to load when theme start
// It can be Google fonts or uploaded fonts, placed in the folder /css/font-face/font-name inside the theme folder
// Attention! Font's folder must have name equal to the font's name, with spaces replaced on the dash '-'

playhockey_storage_set('load_fonts', array(
	// Google font
	array(
		'name'	 => 'Bitter',
		'family' => 'serif',
		'styles' => '400,700'		// Parameter 'style' used only for the Google fonts
		),
    // Google font
    array(
        'name'	 => 'Source Sans Pro',
        'family' => 'sans-serif',
        'styles' => '400,600'		// Parameter 'style' used only for the Google fonts
    )
));

// Characters subset for the Google fonts. Available values are: latin,latin-ext,cyrillic,cyrillic-ext,greek,greek-ext,vietnamese
playhockey_storage_set('load_fonts_subset', 'latin,latin-ext');

// Settings of the main tags
playhockey_storage_set('theme_fonts', array(
	'p' => array(
		'title'				=> esc_html__('Main text', 'playhockey'),
		'description'		=> esc_html__('Font settings of the main text of the site', 'playhockey'),
		'font-family'		=> '"Source Sans Pro", sans-serif',
		'font-size' 		=> '1rem',
		'font-weight'		=> '600',
		'font-style'		=> 'normal',
		'line-height'		=> '1.6em',
		'text-decoration'	=> 'none',
		'text-transform'	=> 'none',
		'letter-spacing'	=> '',
		'margin-top'		=> '0em',
		'margin-bottom'		=> '1.5em'
		),
	'h1' => array(
		'title'				=> esc_html__('Heading 1', 'playhockey'),
		'font-family'		=> '"Bitter",serif',
		'font-size' 		=> '4em',
		'font-weight'		=> '700',
		'font-style'		=> 'normal',
		'line-height'		=> '1.2em',
		'text-decoration'	=> 'none',
		'text-transform'	=> 'uppercase',
		'letter-spacing'	=> '-0.1px',
		'margin-top'		=> '0.9583em',
		'margin-bottom'		=> '0.64em'
		),
	'h2' => array(
		'title'				=> esc_html__('Heading 2', 'playhockey'),
		'font-family'		=> '"Bitter",serif',
		'font-size' 		=> '3.2em',
		'font-weight'		=> '700',
		'font-style'		=> 'normal',
		'line-height'		=> '1.2em',
		'text-decoration'	=> 'none',
		'text-transform'	=> 'uppercase',
		'letter-spacing'	=> '0',
		'margin-top'		=> '1.78em',
		'margin-bottom'		=> '0.85em'
		),
	'h3' => array(
		'title'				=> esc_html__('Heading 3', 'playhockey'),
		'font-family'		=> '"Bitter",serif',
		'font-size' 		=> '2.4em',
		'font-weight'		=> '700',
		'font-style'		=> 'normal',
		'line-height'		=> '1.2em',
		'text-decoration'	=> 'none',
		'text-transform'	=> 'uppercase',
		'letter-spacing'	=> '0.3px',
		'margin-top'		=> '2.63em',
		'margin-bottom'		=> '0.69em'
		),
	'h4' => array(
		'title'				=> esc_html__('Heading 4', 'playhockey'),
		'font-family'		=> '"Bitter",serif',
		'font-size' 		=> '2em',
		'font-weight'		=> '700',
		'font-style'		=> 'normal',
		'line-height'		=> '1.3em',
		'text-decoration'	=> 'none',
		'text-transform'	=> 'uppercase',
		'letter-spacing'	=> '0.2px',
		'margin-top'		=> '3.4em',
		'margin-bottom'		=> '0.5em'
		),
	'h5' => array(
		'title'				=> esc_html__('Heading 5', 'playhockey'),
		'font-family'		=> '"Bitter",serif',
		'font-size' 		=> '1.6em',
		'font-weight'		=> '700',
		'font-style'		=> 'normal',
		'line-height'		=> '1.3em',
		'text-decoration'	=> 'none',
		'text-transform'	=> 'uppercase',
		'letter-spacing'	=> '0',
		'margin-top'		=> '4.11em',
		'margin-bottom'		=> '0.85em'
		),
	'h6' => array(
		'title'				=> esc_html__('Heading 6', 'playhockey'),
		'font-family'		=> '"Bitter",serif',
		'font-size' 		=> '1.133em',
		'font-weight'		=> '700',
		'font-style'		=> 'normal',
		'line-height'		=> '1.2em',
		'text-decoration'	=> 'none',
		'text-transform'	=> 'none',
		'letter-spacing'	=> '0',
		'margin-top'		=> '6.3em',
		'margin-bottom'		=> '1.3412em'
		),
	'logo' => array(
		'title'				=> esc_html__('Logo text', 'playhockey'),
		'description'		=> esc_html__('Font settings of the text case of the logo', 'playhockey'),
		'font-family'		=> '',
		'font-size' 		=> '',
		'font-weight'		=> '',
		'font-style'		=> 'normal',
		'line-height'		=> '',
		'text-decoration'	=> 'none',
		'text-transform'	=> 'uppercase',
		'letter-spacing'	=> ''
		),
	'button' => array(
		'title'				=> esc_html__('Buttons', 'playhockey'),
		'font-family'		=> '"Bitter",serif',
		'font-size' 		=> '0.933em',
		'font-weight'		=> '700',
		'font-style'		=> 'normal',
		'line-height'		=> '1.5em',
		'text-decoration'	=> 'none',
		'text-transform'	=> 'uppercase',
		'letter-spacing'	=> ''
		),
	'input' => array(
		'title'				=> esc_html__('Input fields', 'playhockey'),
		'description'		=> esc_html__('Font settings of the input fields, dropdowns and textareas', 'playhockey'),
		'font-family'		=> '',
		'font-size' 		=> '',
		'font-weight'		=> '',
		'font-style'		=> 'normal',
		'line-height'		=> '',
		'text-decoration'	=> 'none',
		'text-transform'	=> 'none',
		'letter-spacing'	=> ''
		),
	'info' => array(
		'title'				=> esc_html__('Post meta', 'playhockey'),
		'description'		=> esc_html__('Font settings of the post meta: date, counters, share, etc.', 'playhockey'),
		'font-family'		=> '"Bitter",serif',
		'font-size' 		=> '11px',
		'font-weight'		=> '700',
		'font-style'		=> 'normal',
		'line-height'		=> '1.5em',
		'text-decoration'	=> 'none',
		'text-transform'	=> 'uppercase',
		'letter-spacing'	=> '',
		'margin-top'		=> '3.8em',
		'margin-bottom'		=> '2.4em'
		),
	'menu' => array(
		'title'				=> esc_html__('Main menu', 'playhockey'),
		'description'		=> esc_html__('Font settings of the main menu items', 'playhockey'),
		'font-family'		=> '"Bitter",serif',
		'font-size' 		=> '0.933em',
		'font-weight'		=> '700',
		'font-style'		=> 'normal',
		'line-height'		=> '1.333em',
		'text-decoration'	=> 'none',
		'text-transform'	=> 'uppercase',
		'letter-spacing'	=> '1px'
		),
	'submenu' => array(
		'title'				=> esc_html__('Dropdown menu', 'playhockey'),
		'description'		=> esc_html__('Font settings of the dropdown menu items', 'playhockey'),
		'font-family'		=> '"Bitter",serif',
		'font-size' 		=> '14px',
		'font-weight'		=> '700',
		'font-style'		=> 'normal',
		'line-height'		=> '1.5em',
		'text-decoration'	=> 'none',
		'text-transform'	=> 'uppercase',
		'letter-spacing'	=> '1px'
		)
));


// -----------------------------------------------------------------
// -- Theme colors for customizer
// -- Attention! Inner scheme must be last in the array below
// -----------------------------------------------------------------
playhockey_storage_set('schemes', array(

	// Color scheme: 'default'
	'default' => array(
		'title'	 => esc_html__('Default', 'playhockey'),
		'colors' => array(
			
			// Whole block border and background
			'bg_color'				=> '#ffffff',      
			'bd_color'				=> '#e7e8e1',      

			// Text and links colors
			'text'					=> '#9a9c9f',      
			'text_light'			=> '#cfd1d5',      
			'text_dark'				=> '#353940',      
			'text_link'				=> '#ff5335',      
			'text_hover'			=> '#3e92a3',      

			// Alternative blocks (submenu, buttons, tabs, etc.)
			'alter_bg_color'		=> '#f7f7f4',      
			'alter_bg_hover'		=> '#e6e3da',      
			'alter_bd_color'		=> '#ececec',      
			'alter_bd_hover'		=> '#ced5d9',
			'alter_text'			=> '#3cbc81',      
			'alter_light'			=> '#adaeb0',      
			'alter_dark'			=> '#22252b',       
			'alter_link'			=> '#ff6469',
			'alter_hover'			=> '#a1a3a5',      

			// Input fields (form's fields and textarea)
			'input_bg_color'		=> '#fafaf8',      
			'input_bg_hover'		=> '#f9f9f7',      
			'input_bd_color'		=> '#f1f5f8',
			'input_bd_hover'		=> '#e5ecf1',
			'input_text'			=> '#55483b',      
			'input_light'			=> '#bac0c3',
			'input_dark'			=> '#1e1d22',
			
			// Inverse blocks (text and links on accented bg)
			'inverse_text'			=> '#ffffff',       
			'inverse_light'			=> '#f7f7f7',
			'inverse_dark'			=> '#ffffff',
			'inverse_link'			=> '#ffffff',
			'inverse_hover'			=> '#13162b',
		)
	),

	// Color scheme: 'dark'
	'dark' => array(
		'title'  => esc_html__('Dark', 'playhockey'),
		'colors' => array(
			
			// Whole block border and background
			'bg_color'				=> '#22252b',
			'bd_color'				=> '#2b2e41',

			// Text and links colors
			'text'					=> '#8a8c8e',
			'text_light'			=> '#b8c3cc',
			'text_dark'				=> '#f7f7f4',
			'text_link'				=> '#ff5335',
			'text_hover'			=> '#33a1e3',

			// Alternative blocks (submenu, buttons, tabs, etc.)
			'alter_bg_color'		=> '#2b2e34',
			'alter_bg_hover'		=> '#181e3d',
			'alter_bd_color'		=> '#181e3d',
			'alter_bd_hover'		=> '#1f254d',
			'alter_text'			=> '#969fa6',
			'alter_light'			=> '#b8c3cc',
			'alter_dark'			=> '#f7f7f4',
			'alter_link'			=> '#faef81',
			'alter_hover'			=> '#33a1e3',

			// Input fields (form's fields and textarea)
			'input_bg_color'		=> '#0e1123',
			'input_bg_hover'		=> '#181e3d',
			'input_bd_color'		=> '#181e3d',
			'input_bd_hover'		=> '#181e3d',
			'input_text'			=> '#969fa6',
			'input_light'			=> '#b8c3cc',
			'input_dark'			=> '#ffffff',
			
			// Inverse blocks (text and links on accented bg)
			'inverse_text'			=> '#ffffff',
			'inverse_light'			=> '#bac0c3',
			'inverse_dark'			=> '#1e1d22',
			'inverse_link'			=> '#000000',
			'inverse_hover'			=> '#1e1d22',
		)
	),

    // Color scheme: 'dark'
    'superdark' => array(
        'title'  => esc_html__('Super Dark', 'playhockey'),
        'colors' => array(

            // Whole block border and background
            'bg_color'				=> '#22252b',
            'bd_color'				=> '#2b2e41',

            // Text and links colors
            'text'					=> '#ffffff',
            'text_light'			=> '#b8c3cc',
            'text_dark'				=> '#ffffff',
            'text_link'				=> '#ff5335',
            'text_hover'			=> '#33a1e3',

            // Alternative blocks (submenu, buttons, tabs, etc.)
            'alter_bg_color'		=> '#2b2e34',
            'alter_bg_hover'		=> '#181e3d',
            'alter_bd_color'		=> '#181e3d',
            'alter_bd_hover'		=> '#1f254d',
            'alter_text'			=> '#969fa6',
            'alter_light'			=> '#b8c3cc',
            'alter_dark'			=> '#ffffff',
            'alter_link'			=> '#faef81',
            'alter_hover'			=> '#33a1e3',

            // Input fields (form's fields and textarea)
            'input_bg_color'		=> '#0e1123',
            'input_bg_hover'		=> '#181e3d',
            'input_bd_color'		=> '#181e3d',
            'input_bd_hover'		=> '#181e3d',
            'input_text'			=> '#969fa6',
            'input_light'			=> '#b8c3cc',
            'input_dark'			=> '#ffffff',

            // Inverse blocks (text and links on accented bg)
            'inverse_text'			=> '#ffffff',
            'inverse_light'			=> '#bac0c3',
            'inverse_dark'			=> '#1e1d22',
            'inverse_link'			=> '#000000',
            'inverse_hover'			=> '#1e1d22',
        )
    )

));



// -----------------------------------------------------------------
// -- Theme options for customizer
// -----------------------------------------------------------------
if (!function_exists('playhockey_options_create')) {

	function playhockey_options_create() {

		playhockey_storage_set('options', array(
		
			// Section 'Title & Tagline' - add theme options in the standard WP section
			'title_tagline' => array(
				"title" => esc_html__('Title, Tagline & Site icon', 'playhockey'),
				"desc" => wp_kses_data( __('Specify site title and tagline (if need) and upload the site icon', 'playhockey') ),
				"type" => "section"
				),
		
		
			// Section 'Header' - add theme options in the standard WP section
			'header_image' => array(
				"title" => esc_html__('Header', 'playhockey'),
				"desc" => wp_kses_data( __('Select or upload logo images, select header type and widgets set for the header', 'playhockey') ),
				"type" => "section"
				),
			'header_image_override' => array(
				"title" => esc_html__('Header image override', 'playhockey'),
				"desc" => wp_kses_data( __("Allow override the header image with the page's/post's/product's/etc. featured image", 'playhockey') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Header', 'playhockey')
				),
				"std" => 0,
				"type" => "checkbox"
				),
			'header_video' => array(
				"title" => esc_html__('Header video', 'playhockey'),
				"desc" => wp_kses_data( __("Select video to use it as background for the header", 'playhockey') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Header', 'playhockey')
				),
				"std" => '',
				"type" => "video"
				),
			'header_fullheight' => array(
				"title" => esc_html__('Header fullheight', 'playhockey'),
				"desc" => wp_kses_data( __("Enlarge header area to fill whole screen. Used only if header have a background image", 'playhockey') ),
				"override" => array(
					'mode' => 'page,cpt_team',
					'section' => esc_html__('Header', 'playhockey')
				),
				"std" => 0,
				"type" => "checkbox"
				),
			'header_wide' => array(
				"title" => esc_html__('Header fullwide', 'playhockey'),
				"desc" => wp_kses_data( __('Do you want to stretch the header widgets area to the entire window width?', 'playhockey') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Header', 'playhockey')
				),
				"std" => 1,
				"type" => "checkbox"
				),
            'show_page_title' => array(
                "title" => esc_html__('Show Page Title', 'playhockey'),
                "desc" => wp_kses_data( __('Do you want to show page title area (page/post/category title and breadcrumbs)?', 'playhockey') ),
                "override" => array(
                    'mode' => 'page',
                    'section' => esc_html__('Header', 'playhockey')
                ),
                "std" => 1,
                "type" => "checkbox"
            ),
			'header_style' => array(
				"title" => esc_html__('Header style', 'playhockey'),
				"desc" => wp_kses_data( __('Select style to display the site header', 'playhockey') ),
				"override" => array(
					'mode' => 'page,cpt_team',
					'section' => esc_html__('Header', 'playhockey')
				),
				"std" => 'header-default',
				"options" => apply_filters('playhockey_filter_list_header_styles', array(
					'header-default' => esc_html__('Default Header',	'playhockey')
				)),
				"type" => "select"
				),
			'header_position' => array(
				"title" => esc_html__('Header position', 'playhockey'),
				"desc" => wp_kses_data( __('Select position to display the site header', 'playhockey') ),
				"override" => array(
					'mode' => 'page,cpt_team',
					'section' => esc_html__('Header', 'playhockey')
				),
				"std" => 'default',
				"options" => array(
					'default' => esc_html__('Default','playhockey'),
					'over' => esc_html__('Over',	'playhockey'),
					'under' => esc_html__('Under',	'playhockey')
				),
				"type" => "select"
				),
			'header_widgets' => array(
				"title" => esc_html__('Header widgets', 'playhockey'),
				"desc" => wp_kses_data( __('Select set of widgets to show in the header on each page', 'playhockey') ),
				"override" => array(
					'mode' => 'page,cpt_team',
					'section' => esc_html__('Header', 'playhockey'),
					"desc" => wp_kses_data( __('Select set of widgets to show in the header on this page', 'playhockey') ),
				),
				"std" => 'hide',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'playhockey')), playhockey_get_list_sidebars()),
				"type" => "select"
				),
			'header_columns' => array(
				"title" => esc_html__('Header columns', 'playhockey'),
				"desc" => wp_kses_data( __('Select number columns to show widgets in the Header. If 0 - autodetect by the widgets count', 'playhockey') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Header', 'playhockey')
				),
				"dependency" => array(
					'header_widgets' => array('^hide')
				),
				"std" => 0,
				"options" => playhockey_get_list_range(0,6),
				"type" => "select"
				),
			'header_scheme' => array(
				"title" => esc_html__('Header Color Scheme', 'playhockey'),
				"desc" => wp_kses_data( __('Select color scheme to decorate header area', 'playhockey') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Header', 'playhockey')
				),
				"std" => 'inherit',
				"options" => playhockey_get_list_schemes(true),
				"refresh" => false,
				"type" => "select"
				),
			'menu_info' => array(
				"title" => esc_html__('Menu settings', 'playhockey'),
				"desc" => wp_kses_data( __('Select main menu style, position, color scheme and other parameters', 'playhockey') ),
				"type" => "info"
				),
			'menu_style' => array(
				"title" => esc_html__('Menu position', 'playhockey'),
				"desc" => wp_kses_data( __('Select position of the main menu', 'playhockey') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Header', 'playhockey')
				),
				"std" => 'top',
				"options" => array(
					'top'	=> esc_html__('Top',	'playhockey'),
					'left'	=> esc_html__('Left',	'playhockey'),
					'right'	=> esc_html__('Right',	'playhockey')
				),
				"type" => "switch"
				),
			'menu_scheme' => array(
				"title" => esc_html__('Menu Color Scheme', 'playhockey'),
				"desc" => wp_kses_data( __('Select color scheme to decorate main menu area', 'playhockey') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Header', 'playhockey')
				),
				"std" => 'inherit',
				"options" => playhockey_get_list_schemes(true),
				"refresh" => false,
				"type" => "select"
				),
			'menu_side_stretch' => array(
				"title" => esc_html__('Stretch sidemenu', 'playhockey'),
				"desc" => wp_kses_data( __('Stretch sidemenu to window height (if menu items number >= 5)', 'playhockey') ),
				"dependency" => array(
					'menu_style' => array('left', 'right')
				),
				"std" => 1,
				"type" => "checkbox"
				),
			'menu_side_icons' => array(
				"title" => esc_html__('Iconed sidemenu', 'playhockey'),
				"desc" => wp_kses_data( __('Get icons from anchors and display it in the sidemenu or mark sidemenu items with simple dots', 'playhockey') ),
				"dependency" => array(
					'menu_style' => array('left', 'right')
				),
				"std" => 1,
				"type" => "checkbox"
				),
			'menu_mobile_fullscreen' => array(
				"title" => esc_html__('Mobile menu fullscreen', 'playhockey'),
				"desc" => wp_kses_data( __('Display mobile and side menus on full screen (if checked) or slide narrow menu from the left or from the right side (if not checked)', 'playhockey') ),
				"dependency" => array(
					'menu_style' => array('left', 'right')
				),
				"std" => 1,
				"type" => "checkbox"
				),
			'logo_info' => array(
				"title" => esc_html__('Logo settings', 'playhockey'),
				"desc" => wp_kses_data( __('Select logo images for the normal and Retina displays', 'playhockey') ),
				"type" => "info"
				),
			'logo' => array(
				"title" => esc_html__('Logo', 'playhockey'),
				"desc" => wp_kses_data( __('Select or upload site logo', 'playhockey') ),
				"std" => '',
				"type" => "image"
				),
			'logo_retina' => array(
				"title" => esc_html__('Logo for Retina', 'playhockey'),
				"desc" => wp_kses_data( __('Select or upload site logo used on Retina displays (if empty - use default logo from the field above)', 'playhockey') ),
				"std" => '',
				"type" => "image"
				),
			'logo_inverse' => array(
				"title" => esc_html__('Logo inverse', 'playhockey'),
				"desc" => wp_kses_data( __('Select or upload site logo to display it on the dark background', 'playhockey') ),
				"std" => '',
				"type" => "image"
				),
			'logo_inverse_retina' => array(
				"title" => esc_html__('Logo inverse for Retina', 'playhockey'),
				"desc" => wp_kses_data( __('Select or upload site logo used on Retina displays (if empty - use default logo from the field above)', 'playhockey') ),
				"std" => '',
				"type" => "image"
				),
			'logo_side' => array(
				"title" => esc_html__('Logo side', 'playhockey'),
				"desc" => wp_kses_data( __('Select or upload site logo (with vertical orientation) to display it in the side menu', 'playhockey') ),
				"std" => '',
				"type" => "image"
				),
			'logo_side_retina' => array(
				"title" => esc_html__('Logo side for Retina', 'playhockey'),
				"desc" => wp_kses_data( __('Select or upload site logo (with vertical orientation) to display it in the side menu on Retina displays (if empty - use default logo from the field above)', 'playhockey') ),
				"std" => '',
				"type" => "image"
				),
			'logo_text' => array(
				"title" => esc_html__('Logo from Site name', 'playhockey'),
				"desc" => wp_kses_data( __('Do you want use Site name and description as Logo if images above are not selected?', 'playhockey') ),
				"std" => 1,
				"type" => "checkbox"
				),
			
		
		
			// Section 'Content'
			'content' => array(
				"title" => esc_html__('Content', 'playhockey'),
				"desc" => wp_kses_data( __('Options for the content area', 'playhockey') ),
				"type" => "section",
				),
			'body_style' => array(
				"title" => esc_html__('Body style', 'playhockey'),
				"desc" => wp_kses_data( __('Select width of the body content', 'playhockey') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Content', 'playhockey')
				),
				"refresh" => false,
				"std" => 'wide',
				"options" => array(
					'boxed'		=> esc_html__('Boxed',		'playhockey'),
					'wide'		=> esc_html__('Wide',		'playhockey'),
					'fullwide'	=> esc_html__('Fullwide',	'playhockey'),
					'fullscreen'=> esc_html__('Fullscreen',	'playhockey')
				),
				"type" => "select"
				),
			'color_scheme' => array(
				"title" => esc_html__('Site Color Scheme', 'playhockey'),
				"desc" => wp_kses_data( __('Select color scheme to decorate whole site. Attention! Case "Inherit" can be used only for custom pages, not for root site content in the Appearance - Customize', 'playhockey') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Content', 'playhockey')
				),
				"std" => 'default',
				"options" => playhockey_get_list_schemes(true),
				"refresh" => false,
				"type" => "select"
				),
			'expand_content' => array(
				"title" => esc_html__('Expand content', 'playhockey'),
				"desc" => wp_kses_data( __('Expand the content width if the sidebar is hidden', 'playhockey') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Content', 'playhockey')
				),
				"refresh" => false,
				"std" => 1,
				"type" => "checkbox"
				),
			'remove_margins' => array(
				"title" => esc_html__('Remove margins', 'playhockey'),
				"desc" => wp_kses_data( __('Remove margins above and below the content area', 'playhockey') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Content', 'playhockey')
				),
				"refresh" => false,
				"std" => 0,
				"type" => "checkbox"
				),
			'seo_snippets' => array(
				"title" => esc_html__('SEO snippets', 'playhockey'),
				"desc" => wp_kses_data( __('Add structured data markup to the single posts and pages', 'playhockey') ),
				"std" => 0,
				"type" => "checkbox"
				),
            'privacy_text' => array(
                "title" => esc_html__("Text with Privacy Policy link", 'playhockey'),
                "desc"  => wp_kses_data( __("Specify text with Privacy Policy link for the checkbox 'I agree ...'", 'playhockey') ),
                "std"   => wp_kses( __( 'I agree that my submitted data is being collected and stored.', 'playhockey'), 'playhockey_kses_content' ),
                "type"  => "text"
            ),
			'boxed_bg_image' => array(
				"title" => esc_html__('Boxed bg image', 'playhockey'),
				"desc" => wp_kses_data( __('Select or upload image, used as background in the boxed body', 'playhockey') ),
				"dependency" => array(
					'body_style' => array('boxed')
				),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Content', 'playhockey')
				),
				"std" => '',
				"type" => "image"
				),
			'no_image' => array(
				"title" => esc_html__('No image placeholder', 'playhockey'),
				"desc" => wp_kses_data( __('Select or upload image, used as placeholder for the posts without featured image', 'playhockey') ),
				"std" => '',
				"type" => "image"
				),
			'sidebar_widgets' => array(
				"title" => esc_html__('Sidebar widgets', 'playhockey'),
				"desc" => wp_kses_data( __('Select default widgets to show in the sidebar', 'playhockey') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Widgets', 'playhockey')
				),
				"std" => 'sidebar_widgets',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'playhockey')), playhockey_get_list_sidebars()),
				"type" => "select"
				),
			'sidebar_scheme' => array(
				"title" => esc_html__('Color Scheme', 'playhockey'),
				"desc" => wp_kses_data( __('Select color scheme to decorate sidebar', 'playhockey') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Widgets', 'playhockey')
				),
				"std" => 'side',
				"options" => playhockey_get_list_schemes(true),
				"refresh" => false,
				"type" => "select"
				),
			'sidebar_position' => array(
				"title" => esc_html__('Sidebar position', 'playhockey'),
				"desc" => wp_kses_data( __('Select position to show sidebar', 'playhockey') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Widgets', 'playhockey')
				),
				"refresh" => false,
				"std" => 'right',
				"options" => playhockey_get_list_sidebars_positions(),
				"type" => "select"
				),
			'widgets_above_page' => array(
				"title" => esc_html__('Widgets above the page', 'playhockey'),
				"desc" => wp_kses_data( __('Select widgets to show above page (content and sidebar)', 'playhockey') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Widgets', 'playhockey')
				),
				"std" => 'hide',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'playhockey')), playhockey_get_list_sidebars()),
				"type" => "select"
				),
			'widgets_above_content' => array(
				"title" => esc_html__('Widgets above the content', 'playhockey'),
				"desc" => wp_kses_data( __('Select widgets to show at the beginning of the content area', 'playhockey') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Widgets', 'playhockey')
				),
				"std" => 'hide',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'playhockey')), playhockey_get_list_sidebars()),
				"type" => "select"
				),
			'widgets_below_content' => array(
				"title" => esc_html__('Widgets below the content', 'playhockey'),
				"desc" => wp_kses_data( __('Select widgets to show at the ending of the content area', 'playhockey') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Widgets', 'playhockey')
				),
				"std" => 'hide',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'playhockey')), playhockey_get_list_sidebars()),
				"type" => "select"
				),
			'widgets_below_page' => array(
				"title" => esc_html__('Widgets below the page', 'playhockey'),
				"desc" => wp_kses_data( __('Select widgets to show below the page (content and sidebar)', 'playhockey') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Widgets', 'playhockey')
				),
				"std" => 'hide',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'playhockey')), playhockey_get_list_sidebars()),
				"type" => "select"
				),
		
		
		
			// Section 'Footer'
			'footer' => array(
				"title" => esc_html__('Footer', 'playhockey'),
				"desc" => wp_kses_data( __('Select set of widgets and columns number for the site footer', 'playhockey') ),
				"type" => "section"
				),
			'footer_style' => array(
				"title" => esc_html__('Footer style', 'playhockey'),
				"desc" => wp_kses_data( __('Select style to display the site footer', 'playhockey') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Footer', 'playhockey')
				),
				"std" => 'footer-default',
				"options" => apply_filters('playhockey_filter_list_footer_styles', array(
					'footer-default' => esc_html__('Default Footer',	'playhockey')
				)),
				"type" => "select"
				),
			'footer_scheme' => array(
				"title" => esc_html__('Footer Color Scheme', 'playhockey'),
				"desc" => wp_kses_data( __('Select color scheme to decorate footer area', 'playhockey') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Footer', 'playhockey')
				),
				"std" => 'default',
				"options" => playhockey_get_list_schemes(true),
				"refresh" => false,
				"type" => "select"
				),
			'footer_widgets' => array(
				"title" => esc_html__('Footer widgets', 'playhockey'),
				"desc" => wp_kses_data( __('Select set of widgets to show in the footer', 'playhockey') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Footer', 'playhockey')
				),
				"std" => 'footer_widgets',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'playhockey')), playhockey_get_list_sidebars()),
				"type" => "select"
				),
			'footer_columns' => array(
				"title" => esc_html__('Footer columns', 'playhockey'),
				"desc" => wp_kses_data( __('Select number columns to show widgets in the footer. If 0 - autodetect by the widgets count', 'playhockey') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Footer', 'playhockey')
				),
				"dependency" => array(
					'footer_widgets' => array('^hide')
				),
				"std" => 3,
				"options" => playhockey_get_list_range(0,6),
				"type" => "select"
				),
			'footer_wide' => array(
				"title" => esc_html__('Footer fullwide', 'playhockey'),
				"desc" => wp_kses_data( __('Do you want to stretch the footer to the entire window width?', 'playhockey') ),
				"override" => array(
					'mode' => 'page,cpt_team,cpt_services,cpt_courses,cpt_portfolio',
					'section' => esc_html__('Footer', 'playhockey')
				),
				"std" => 0,
				"type" => "checkbox"
				),
			'logo_in_footer' => array(
				"title" => esc_html__('Show logo', 'playhockey'),
				"desc" => wp_kses_data( __('Show logo in the footer', 'playhockey') ),
				'refresh' => false,
				"std" => 0,
				"type" => "checkbox"
				),
			'logo_footer' => array(
				"title" => esc_html__('Logo for footer', 'playhockey'),
				"desc" => wp_kses_data( __('Select or upload site logo to display it in the footer', 'playhockey') ),
				"dependency" => array(
					'logo_in_footer' => array('1')
				),
				"std" => '',
				"type" => "image"
				),
			'logo_footer_retina' => array(
				"title" => esc_html__('Logo for footer (Retina)', 'playhockey'),
				"desc" => wp_kses_data( __('Select or upload logo for the footer area used on Retina displays (if empty - use default logo from the field above)', 'playhockey') ),
				"dependency" => array(
					'logo_in_footer' => array('1')
				),
				"std" => '',
				"type" => "image"
				),
			'socials_in_footer' => array(
				"title" => esc_html__('Show social icons', 'playhockey'),
				"desc" => wp_kses_data( __('Show social icons in the footer (under logo or footer widgets)', 'playhockey') ),
				"std" => 0,
				"type" => "checkbox"
				),
			'copyright' => array(
				"title" => esc_html__('Copyright', 'playhockey'),
				"desc" => wp_kses_data( __('Copyright text in the footer', 'playhockey') ),
				"std" => esc_html__('AxiomThemes &copy; {Y}. All rights reserved. Terms of use and Privacy Policy', 'playhockey'),
				"refresh" => false,
				"type" => "textarea"
				),
		
		
		
			// Section 'Homepage' - settings for home page
			'homepage' => array(
				"title" => esc_html__('Homepage', 'playhockey'),
				"desc" => wp_kses_data( __('Select blog style and widgets to display on the homepage', 'playhockey') ),
				"type" => "section"
				),
			'expand_content_home' => array(
				"title" => esc_html__('Expand content', 'playhockey'),
				"desc" => wp_kses_data( __('Expand the content width if the sidebar is hidden on the Homepage', 'playhockey') ),
				"refresh" => false,
				"std" => 1,
				"type" => "checkbox"
				),
			'blog_style_home' => array(
				"title" => esc_html__('Blog style', 'playhockey'),
				"desc" => wp_kses_data( __('Select posts style for the homepage', 'playhockey') ),
				"std" => 'excerpt',
				"options" => playhockey_get_list_blog_styles(),
				"type" => "select"
				),
			'first_post_large_home' => array(
				"title" => esc_html__('First post large', 'playhockey'),
				"desc" => wp_kses_data( __('Make first post large (with Excerpt layout) on the Classic layout of the Homepage', 'playhockey') ),
				"dependency" => array(
					'blog_style_home' => array('classic')
				),
				"std" => 0,
				"type" => "checkbox"
				),
			'header_widgets_home' => array(
				"title" => esc_html__('Header widgets', 'playhockey'),
				"desc" => wp_kses_data( __('Select set of widgets to show in the header on the homepage', 'playhockey') ),
				"std" => 'header_widgets',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'playhockey')), playhockey_get_list_sidebars()),
				"type" => "select"
				),
			'sidebar_widgets_home' => array(
				"title" => esc_html__('Sidebar widgets', 'playhockey'),
				"desc" => wp_kses_data( __('Select sidebar to show on the homepage', 'playhockey') ),
				"std" => 'sidebar_widgets',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'playhockey')), playhockey_get_list_sidebars()),
				"type" => "select"
				),
			'sidebar_position_home' => array(
				"title" => esc_html__('Sidebar position', 'playhockey'),
				"desc" => wp_kses_data( __('Select position to show sidebar on the homepage', 'playhockey') ),
				"refresh" => false,
				"std" => 'right',
				"options" => playhockey_get_list_sidebars_positions(),
				"type" => "select"
				),
			'widgets_above_page_home' => array(
				"title" => esc_html__('Widgets above the page', 'playhockey'),
				"desc" => wp_kses_data( __('Select widgets to show above page (content and sidebar)', 'playhockey') ),
				"std" => 'hide',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'playhockey')), playhockey_get_list_sidebars()),
				"type" => "select"
				),
			'widgets_above_content_home' => array(
				"title" => esc_html__('Widgets above the content', 'playhockey'),
				"desc" => wp_kses_data( __('Select widgets to show at the beginning of the content area', 'playhockey') ),
				"std" => 'hide',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'playhockey')), playhockey_get_list_sidebars()),
				"type" => "select"
				),
			'widgets_below_content_home' => array(
				"title" => esc_html__('Widgets below the content', 'playhockey'),
				"desc" => wp_kses_data( __('Select widgets to show at the ending of the content area', 'playhockey') ),
				"std" => 'hide',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'playhockey')), playhockey_get_list_sidebars()),
				"type" => "select"
				),
			'widgets_below_page_home' => array(
				"title" => esc_html__('Widgets below the page', 'playhockey'),
				"desc" => wp_kses_data( __('Select widgets to show below the page (content and sidebar)', 'playhockey') ),
				"std" => 'hide',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'playhockey')), playhockey_get_list_sidebars()),
				"type" => "select"
				),
			
		
		
			// Section 'Blog archive'
			'blog' => array(
				"title" => esc_html__('Blog archive', 'playhockey'),
				"desc" => wp_kses_data( __('Options for the blog archive', 'playhockey') ),
				"type" => "section",
				),
			'expand_content_blog' => array(
				"title" => esc_html__('Expand content', 'playhockey'),
				"desc" => wp_kses_data( __('Expand the content width if the sidebar is hidden on the blog archive', 'playhockey') ),
				"refresh" => false,
				"std" => 1,
				"type" => "checkbox"
				),
			'blog_style' => array(
				"title" => esc_html__('Blog style', 'playhockey'),
				"desc" => wp_kses_data( __('Select posts style for the blog archive', 'playhockey') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Content', 'playhockey')
				),
				"dependency" => array(
                    '#page_template' => array( 'blog.php' ),
                    '.editor-page-attributes__template select' => array( 'blog.php' ),
				),
				"std" => 'excerpt',
				"options" => playhockey_get_list_blog_styles(),
				"type" => "select"
				),
			'blog_columns' => array(
				"title" => esc_html__('Blog columns', 'playhockey'),
				"desc" => wp_kses_data( __('How many columns should be used in the blog archive (from 2 to 4)?', 'playhockey') ),
				"std" => 2,
				"options" => playhockey_get_list_range(2,4),
				"type" => "hidden"
				),
			'post_type' => array(
				"title" => esc_html__('Post type', 'playhockey'),
				"desc" => wp_kses_data( __('Select post type to show in the blog archive', 'playhockey') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Content', 'playhockey')
				),
				"dependency" => array(
                    '#page_template' => array( 'blog.php' ),
                    '.editor-page-attributes__template select' => array( 'blog.php' ),
				),
				"linked" => 'parent_cat',
				"refresh" => false,
				"hidden" => true,
				"std" => 'post',
				"options" => playhockey_get_list_posts_types(),
				"type" => "select"
				),
			'parent_cat' => array(
				"title" => esc_html__('Category to show', 'playhockey'),
				"desc" => wp_kses_data( __('Select category to show in the blog archive', 'playhockey') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Content', 'playhockey')
				),
				"dependency" => array(
                    '#page_template' => array( 'blog.php' ),
                    '.editor-page-attributes__template select' => array( 'blog.php' ),
				),
				"refresh" => false,
				"hidden" => true,
				"std" => '0',
				"options" => playhockey_array_merge(array(0 => esc_html__('- Select category -', 'playhockey')), playhockey_get_list_categories()),
				"type" => "select"
				),
			'posts_per_page' => array(
				"title" => esc_html__('Posts per page', 'playhockey'),
				"desc" => wp_kses_data( __('How many posts will be displayed on this page', 'playhockey') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Content', 'playhockey')
				),
				"dependency" => array(
                    '#page_template' => array( 'blog.php' ),
                    '.editor-page-attributes__template select' => array( 'blog.php' ),
				),
				"hidden" => true,
				"std" => '10',
				"type" => "text"
				),
			"blog_pagination" => array( 
				"title" => esc_html__('Pagination style', 'playhockey'),
				"desc" => wp_kses_data( __('Show Older/Newest posts or Page numbers below the posts list', 'playhockey') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Content', 'playhockey')
				),
				"std" => "links",
				"options" => array(
					'pages'	=> esc_html__("Page numbers", 'playhockey'),
					'links'	=> esc_html__("Older/Newest", 'playhockey'),
					'more'	=> esc_html__("Load more", 'playhockey'),
					'infinite' => esc_html__("Infinite scroll", 'playhockey')
				),
				"type" => "select"
				),
			'show_filters' => array(
				"title" => esc_html__('Show filters', 'playhockey'),
				"desc" => wp_kses_data( __('Show categories as tabs to filter posts', 'playhockey') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Content', 'playhockey')
				),
				"dependency" => array(
                    '#page_template' => array( 'blog.php' ),
                    '.editor-page-attributes__template select' => array( 'blog.php' ),
					'blog_style' => array('portfolio', 'gallery')
				),
				"hidden" => true,
				"std" => 0,
				"type" => "checkbox"
				),
			'first_post_large' => array(
				"title" => esc_html__('First post large', 'playhockey'),
				"desc" => wp_kses_data( __('Make first post large (with Excerpt layout) on the Classic layout of blog archive', 'playhockey') ),
				"dependency" => array(
					'blog_style' => array('classic')
				),
				"std" => 0,
				"type" => "checkbox"
				),
			"blog_content" => array( 
				"title" => esc_html__('Posts content', 'playhockey'),
				"desc" => wp_kses_data( __("Show full post's content in the blog or only post's excerpt", 'playhockey') ),
				"std" => "excerpt",
				"options" => array(
					'excerpt'	=> esc_html__('Excerpt',	'playhockey'),
					'fullpost'	=> esc_html__('Full post',	'playhockey')
				),
				"type" => "select"
				),
			'time_diff_before' => array(
				"title" => esc_html__('Time difference', 'playhockey'),
				"desc" => wp_kses_data( __("How many days show time difference instead post's date", 'playhockey') ),
				"std" => 5,
				"type" => "text"
				),
			'related_posts' => array(
				"title" => esc_html__('Related posts', 'playhockey'),
				"desc" => wp_kses_data( __('How many related posts should be displayed in the single post?', 'playhockey') ),
				"std" => 2,
				"options" => playhockey_get_list_range(2,4),
				"type" => "select"
				),
			"blog_animation" => array( 
				"title" => esc_html__('Animation for the posts', 'playhockey'),
				"desc" => wp_kses_data( __('Select animation to show posts in the blog. Attention! Do not use any animation on pages with the "wheel to the anchor" behaviour (like a "Chess 2 columns")!', 'playhockey') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Content', 'playhockey')
				),
				"dependency" => array(
                    '#page_template' => array( 'blog.php' ),
                    '.editor-page-attributes__template select' => array( 'blog.php' ),
				),
				"std" => "none",
				"options" => playhockey_get_list_animations_in(),
				"type" => "select"
				),
			'header_widgets_blog' => array(
				"title" => esc_html__('Header widgets', 'playhockey'),
				"desc" => wp_kses_data( __('Select set of widgets to show in the header on the blog archive', 'playhockey') ),
				"std" => 'hide',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'playhockey')), playhockey_get_list_sidebars()),
				"type" => "select"
				),
			'sidebar_widgets_blog' => array(
				"title" => esc_html__('Sidebar widgets', 'playhockey'),
				"desc" => wp_kses_data( __('Select sidebar to show on the blog archive', 'playhockey') ),
				"std" => 'sidebar_widgets',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'playhockey')), playhockey_get_list_sidebars()),
				"type" => "select"
				),
			'sidebar_position_blog' => array(
				"title" => esc_html__('Sidebar position', 'playhockey'),
				"desc" => wp_kses_data( __('Select position to show sidebar on the blog archive', 'playhockey') ),
				"refresh" => false,
				"std" => 'right',
				"options" => playhockey_get_list_sidebars_positions(),
				"type" => "select"
				),
			'widgets_above_page_blog' => array(
				"title" => esc_html__('Widgets above the page', 'playhockey'),
				"desc" => wp_kses_data( __('Select widgets to show above page (content and sidebar)', 'playhockey') ),
				"std" => 'hide',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'playhockey')), playhockey_get_list_sidebars()),
				"type" => "select"
				),
			'widgets_above_content_blog' => array(
				"title" => esc_html__('Widgets above the content', 'playhockey'),
				"desc" => wp_kses_data( __('Select widgets to show at the beginning of the content area', 'playhockey') ),
				"std" => 'hide',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'playhockey')), playhockey_get_list_sidebars()),
				"type" => "select"
				),
			'widgets_below_content_blog' => array(
				"title" => esc_html__('Widgets below the content', 'playhockey'),
				"desc" => wp_kses_data( __('Select widgets to show at the ending of the content area', 'playhockey') ),
				"std" => 'hide',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'playhockey')), playhockey_get_list_sidebars()),
				"type" => "select"
				),
			'widgets_below_page_blog' => array(
				"title" => esc_html__('Widgets below the page', 'playhockey'),
				"desc" => wp_kses_data( __('Select widgets to show below the page (content and sidebar)', 'playhockey') ),
				"std" => 'hide',
				"options" => array_merge(array('hide'=>esc_html__('- Select widgets -', 'playhockey')), playhockey_get_list_sidebars()),
				"type" => "select"
				),
			
		
		
		
			// Section 'Colors' - choose color scheme and customize separate colors from it
			'scheme' => array(
				"title" => esc_html__('* Color scheme editor', 'playhockey'),
				"desc" => wp_kses_data( __("<b>Simple settings</b> - you can change only accented color, used for links, buttons and some accented areas.", 'playhockey') )
						. '<br>'
						. wp_kses_data( __("<b>Advanced settings</b> - change all scheme's colors and get full control over the appearance of your site!", 'playhockey') ),
				"priority" => 1000,
				"type" => "section"
				),
		
			'color_settings' => array(
				"title" => esc_html__('Color settings', 'playhockey'),
				"desc" => '',
				"std" => 'simple',
				"options" => array(
					"simple"  => esc_html__("Simple", 'playhockey'),
					"advanced" => esc_html__("Advanced", 'playhockey')
				),
				"refresh" => false,
				"type" => "switch"
				),
		
			'color_scheme_editor' => array(
				"title" => esc_html__('Color Scheme', 'playhockey'),
				"desc" => wp_kses_data( __('Select color scheme to edit colors', 'playhockey') ),
				"std" => 'default',
				"options" => playhockey_get_list_schemes(),
				"refresh" => false,
				"type" => "select"
				),
		
			'scheme_storage' => array(
				"title" => esc_html__('Colors storage', 'playhockey'),
				"desc" => esc_html__('Hidden storage of the all color from the all color shemes (only for internal usage)', 'playhockey'),
				"std" => '',
				"refresh" => false,
				"type" => "hidden"
				),
		
			'scheme_info_single' => array(
				"title" => esc_html__('Colors for single post/page', 'playhockey'),
				"desc" => wp_kses_data( __('Specify colors for single post/page (not for alter blocks)', 'playhockey') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"type" => "info"
				),
				
			'bg_color' => array(
				"title" => esc_html__('Background color', 'playhockey'),
				"desc" => wp_kses_data( __('Background color of the whole page', 'playhockey') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$playhockey_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'bd_color' => array(
				"title" => esc_html__('Border color', 'playhockey'),
				"desc" => wp_kses_data( __('Color of the bordered elements, separators, etc.', 'playhockey') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$playhockey_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
		
			'text' => array(
				"title" => esc_html__('Text', 'playhockey'),
				"desc" => wp_kses_data( __('Plain text color on single page/post', 'playhockey') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$playhockey_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'text_light' => array(
				"title" => esc_html__('Light text', 'playhockey'),
				"desc" => wp_kses_data( __('Color of the post meta: post date and author, comments number, etc.', 'playhockey') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$playhockey_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'text_dark' => array(
				"title" => esc_html__('Dark text', 'playhockey'),
				"desc" => wp_kses_data( __('Color of the headers, strong text, etc.', 'playhockey') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$playhockey_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'text_link' => array(
				"title" => esc_html__('Links', 'playhockey'),
				"desc" => wp_kses_data( __('Color of links and accented areas', 'playhockey') ),
				"std" => '$playhockey_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'text_hover' => array(
				"title" => esc_html__('Links hover', 'playhockey'),
				"desc" => wp_kses_data( __('Hover color for links and accented areas', 'playhockey') ),
				"std" => '$playhockey_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
		
			'scheme_info_alter' => array(
				"title" => esc_html__('Colors for alternative blocks', 'playhockey'),
				"desc" => wp_kses_data( __('Specify colors for alternative blocks - rectangular blocks with its own background color (posts in homepage, blog archive, search results, widgets on sidebar, footer, etc.)', 'playhockey') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"type" => "info"
				),
		
			'alter_bg_color' => array(
				"title" => esc_html__('Alter background color', 'playhockey'),
				"desc" => wp_kses_data( __('Background color of the alternative blocks', 'playhockey') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$playhockey_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'alter_bg_hover' => array(
				"title" => esc_html__('Alter hovered background color', 'playhockey'),
				"desc" => wp_kses_data( __('Background color for the hovered state of the alternative blocks', 'playhockey') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$playhockey_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'alter_bd_color' => array(
				"title" => esc_html__('Alternative border color', 'playhockey'),
				"desc" => wp_kses_data( __('Border color of the alternative blocks', 'playhockey') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$playhockey_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'alter_bd_hover' => array(
				"title" => esc_html__('Alternative hovered border color', 'playhockey'),
				"desc" => wp_kses_data( __('Border color for the hovered state of the alter blocks', 'playhockey') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$playhockey_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'alter_text' => array(
				"title" => esc_html__('Alter text', 'playhockey'),
				"desc" => wp_kses_data( __('Text color of the alternative blocks', 'playhockey') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$playhockey_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'alter_light' => array(
				"title" => esc_html__('Alter light', 'playhockey'),
				"desc" => wp_kses_data( __('Color of the info blocks inside block with alternative background', 'playhockey') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$playhockey_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'alter_dark' => array(
				"title" => esc_html__('Alter dark', 'playhockey'),
				"desc" => wp_kses_data( __('Color of the headers inside block with alternative background', 'playhockey') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$playhockey_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'alter_link' => array(
				"title" => esc_html__('Alter link', 'playhockey'),
				"desc" => wp_kses_data( __('Color of the links inside block with alternative background', 'playhockey') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$playhockey_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'alter_hover' => array(
				"title" => esc_html__('Alter hover', 'playhockey'),
				"desc" => wp_kses_data( __('Color of the hovered links inside block with alternative background', 'playhockey') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$playhockey_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
		
			'scheme_info_input' => array(
				"title" => esc_html__('Colors for the form fields', 'playhockey'),
				"desc" => wp_kses_data( __('Specify colors for the form fields and textareas', 'playhockey') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"type" => "info"
				),
		
			'input_bg_color' => array(
				"title" => esc_html__('Inactive background', 'playhockey'),
				"desc" => wp_kses_data( __('Background color of the inactive form fields', 'playhockey') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$playhockey_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'input_bg_hover' => array(
				"title" => esc_html__('Active background', 'playhockey'),
				"desc" => wp_kses_data( __('Background color of the focused form fields', 'playhockey') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$playhockey_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'input_bd_color' => array(
				"title" => esc_html__('Inactive border', 'playhockey'),
				"desc" => wp_kses_data( __('Color of the border in the inactive form fields', 'playhockey') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$playhockey_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'input_bd_hover' => array(
				"title" => esc_html__('Active border', 'playhockey'),
				"desc" => wp_kses_data( __('Color of the border in the focused form fields', 'playhockey') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$playhockey_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'input_text' => array(
				"title" => esc_html__('Inactive field', 'playhockey'),
				"desc" => wp_kses_data( __('Color of the text in the inactive fields', 'playhockey') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$playhockey_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'input_light' => array(
				"title" => esc_html__('Disabled field', 'playhockey'),
				"desc" => wp_kses_data( __('Color of the disabled field', 'playhockey') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$playhockey_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'input_dark' => array(
				"title" => esc_html__('Active field', 'playhockey'),
				"desc" => wp_kses_data( __('Color of the active field', 'playhockey') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$playhockey_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
		
			'scheme_info_inverse' => array(
				"title" => esc_html__('Colors for inverse blocks', 'playhockey'),
				"desc" => wp_kses_data( __('Specify colors for inverse blocks, rectangular blocks with background color equal to the links color or one of accented colors (if used in the current theme)', 'playhockey') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"type" => "info"
				),
		
			'inverse_text' => array(
				"title" => esc_html__('Inverse text', 'playhockey'),
				"desc" => wp_kses_data( __('Color of the text inside block with accented background', 'playhockey') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$playhockey_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'inverse_light' => array(
				"title" => esc_html__('Inverse light', 'playhockey'),
				"desc" => wp_kses_data( __('Color of the info blocks inside block with accented background', 'playhockey') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$playhockey_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'inverse_dark' => array(
				"title" => esc_html__('Inverse dark', 'playhockey'),
				"desc" => wp_kses_data( __('Color of the headers inside block with accented background', 'playhockey') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$playhockey_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'inverse_link' => array(
				"title" => esc_html__('Inverse link', 'playhockey'),
				"desc" => wp_kses_data( __('Color of the links inside block with accented background', 'playhockey') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$playhockey_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),
			'inverse_hover' => array(
				"title" => esc_html__('Inverse hover', 'playhockey'),
				"desc" => wp_kses_data( __('Color of the hovered links inside block with accented background', 'playhockey') ),
				"dependency" => array(
					'color_settings' => array('^simple')
				),
				"std" => '$playhockey_get_scheme_color',
				"refresh" => false,
				"type" => "color"
				),


			// Section 'Hidden'
			'media_title' => array(
				"title" => esc_html__('Media title', 'playhockey'),
				"desc" => wp_kses_data( __('Used as title for the audio and video item in this post', 'playhockey') ),
				"override" => array(
					'mode' => 'post',
					'section' => esc_html__('Title', 'playhockey')
				),
				"hidden" => true,
				"std" => '',
				"type" => "text"
				),
			'media_author' => array(
				"title" => esc_html__('Media author', 'playhockey'),
				"desc" => wp_kses_data( __('Used as author name for the audio and video item in this post', 'playhockey') ),
				"override" => array(
					'mode' => 'post',
					'section' => esc_html__('Title', 'playhockey')
				),
				"hidden" => true,
				"std" => '',
				"type" => "text"
				),


			// Internal options.
			// Attention! Don't change any options in the section below!
			'reset_options' => array(
				"title" => '',
				"desc" => '',
				"std" => '0',
				"type" => "hidden",
				),

		));


		// Prepare panel 'Fonts'
		$fonts = array(
		
			// Panel 'Fonts' - manage fonts loading and set parameters of the base theme elements
			'fonts' => array(
				"title" => esc_html__('* Fonts settings', 'playhockey'),
				"desc" => '',
				"priority" => 1500,
				"type" => "panel"
				),

			// Section 'Load_fonts'
			'load_fonts' => array(
				"title" => esc_html__('Load fonts', 'playhockey'),
				"desc" => wp_kses_data( __('Specify fonts to load when theme start. You can use them in the base theme elements: headers, text, menu, links, input fields, etc.', 'playhockey') )
						. '<br>'
						. wp_kses_data( __('<b>Attention!</b> Press "Refresh" button to reload preview area after the all fonts are changed', 'playhockey') ),
				"type" => "section"
				),
			'load_fonts_subset' => array(
				"title" => esc_html__('Google fonts subsets', 'playhockey'),
				"desc" => wp_kses_data( __('Specify comma separated list of the subsets which will be load from Google fonts', 'playhockey') )
						. '<br>'
						. wp_kses_data( __('Available subsets are: latin,latin-ext,cyrillic,cyrillic-ext,greek,greek-ext,vietnamese', 'playhockey') ),
				"refresh" => false,
				"std" => '$playhockey_get_load_fonts_subset',
				"type" => "text"
				)
		);

		for ($i=1; $i<=playhockey_get_theme_setting('max_load_fonts'); $i++) {
			$fonts["load_fonts-{$i}-info"] = array(
				"title" => esc_html(sprintf(__('Font %s', 'playhockey'), $i)),
				"desc" => '',
				"type" => "info",
				);
			$fonts["load_fonts-{$i}-name"] = array(
				"title" => esc_html__('Font name', 'playhockey'),
				"desc" => '',
				"refresh" => false,
				"std" => '$playhockey_get_load_fonts_option',
				"type" => "text"
				);
			$fonts["load_fonts-{$i}-family"] = array(
				"title" => esc_html__('Font family', 'playhockey'),
				"desc" => $i==1 
							? wp_kses_data( __('Select font family to use it if font above is not available', 'playhockey') )
							: '',
				"refresh" => false,
				"std" => '$playhockey_get_load_fonts_option',
				"options" => array(
					'inherit' => esc_html__("Inherit", 'playhockey'),
					'serif' => esc_html__('serif', 'playhockey'),
					'sans-serif' => esc_html__('sans-serif', 'playhockey'),
					'monospace' => esc_html__('monospace', 'playhockey'),
					'cursive' => esc_html__('cursive', 'playhockey'),
					'fantasy' => esc_html__('fantasy', 'playhockey')
				),
				"type" => "select"
				);
			$fonts["load_fonts-{$i}-styles"] = array(
				"title" => esc_html__('Font styles', 'playhockey'),
				"desc" => $i==1 
							? wp_kses_data( __('Font styles used only for the Google fonts. This is a comma separated list of the font weight and styles. For example: 400,400italic,700', 'playhockey') )
											. '<br>'
								. wp_kses_data( __('<b>Attention!</b> Each weight and style increase download size! Specify only used weights and styles.', 'playhockey') )
							: '',
				"refresh" => false,
				"std" => '$playhockey_get_load_fonts_option',
				"type" => "text"
				);
		}
		$fonts['load_fonts_end'] = array(
			"type" => "section_end"
			);

		// Sections with font's attributes for each theme element
		$theme_fonts = playhockey_get_theme_fonts();
		foreach ($theme_fonts as $tag=>$v) {
			$fonts["{$tag}_section"] = array(
				"title" => !empty($v['title']) 
								? $v['title'] 
								: esc_html(sprintf(__('%s settings', 'playhockey'), $tag)),
				"desc" => !empty($v['description']) 
								? $v['description'] 
								: wp_kses( sprintf(__('Font settings of the "%s" tag.', 'playhockey'), $tag), 'playhockey_kses_content' ),
				"type" => "section",
				);
	
			foreach ($v as $css_prop=>$css_value) {
				if (in_array($css_prop, array('title', 'description'))) continue;
				$options = '';
				$type = 'text';
				$title = ucfirst(str_replace('-', ' ', $css_prop));
				if ($css_prop == 'font-family') {
					$type = 'select';
					$options = playhockey_get_list_load_fonts(true);
				} else if ($css_prop == 'font-weight') {
					$type = 'select';
					$options = array(
						'inherit' => esc_html__("Inherit", 'playhockey'),
						'100' => esc_html__('100 (Light)', 'playhockey'), 
						'200' => esc_html__('200 (Light)', 'playhockey'), 
						'300' => esc_html__('300 (Thin)',  'playhockey'),
						'400' => esc_html__('400 (Normal)', 'playhockey'),
						'500' => esc_html__('500 (Semibold)', 'playhockey'),
						'600' => esc_html__('600 (Semibold)', 'playhockey'),
						'700' => esc_html__('700 (Bold)', 'playhockey'),
						'800' => esc_html__('800 (Black)', 'playhockey'),
						'900' => esc_html__('900 (Black)', 'playhockey')
					);
				} else if ($css_prop == 'font-style') {
					$type = 'select';
					$options = array(
						'inherit' => esc_html__("Inherit", 'playhockey'),
						'normal' => esc_html__('Normal', 'playhockey'), 
						'italic' => esc_html__('Italic', 'playhockey')
					);
				} else if ($css_prop == 'text-decoration') {
					$type = 'select';
					$options = array(
						'inherit' => esc_html__("Inherit", 'playhockey'),
						'none' => esc_html__('None', 'playhockey'), 
						'underline' => esc_html__('Underline', 'playhockey'),
						'overline' => esc_html__('Overline', 'playhockey'),
						'line-through' => esc_html__('Line-through', 'playhockey')
					);
				} else if ($css_prop == 'text-transform') {
					$type = 'select';
					$options = array(
						'inherit' => esc_html__("Inherit", 'playhockey'),
						'none' => esc_html__('None', 'playhockey'), 
						'uppercase' => esc_html__('Uppercase', 'playhockey'),
						'lowercase' => esc_html__('Lowercase', 'playhockey'),
						'capitalize' => esc_html__('Capitalize', 'playhockey')
					);
				}
				$fonts["{$tag}_{$css_prop}"] = array(
					"title" => $title,
					"desc" => '',
					"refresh" => false,
					"std" => '$playhockey_get_theme_fonts_option',
					"options" => $options,
					"type" => $type
				);
			}
			
			$fonts["{$tag}_section_end"] = array(
				"type" => "section_end"
				);
		}

		$fonts['fonts_end'] = array(
			"type" => "panel_end"
			);

		// Add fonts parameters into Theme Options
		playhockey_storage_merge_array('options', '', $fonts);
	}
}




// -----------------------------------------------------------------
// -- Create and manage Theme Options
// -----------------------------------------------------------------

// Theme init priorities:
// 2 - create Theme Options
if (!function_exists('playhockey_options_theme_setup2')) {
	add_action( 'after_setup_theme', 'playhockey_options_theme_setup2', 2 );
	function playhockey_options_theme_setup2() {
		playhockey_options_create();
	}
}

// Step 1: Load default settings and previously saved mods
if (!function_exists('playhockey_options_theme_setup5')) {
	add_action( 'after_setup_theme', 'playhockey_options_theme_setup5', 5 );
	function playhockey_options_theme_setup5() {
		playhockey_storage_set('options_reloaded', false);
		playhockey_load_theme_options();
	}
}

// Step 2: Load current theme customization mods
if (is_customize_preview()) {
	if (!function_exists('playhockey_load_custom_options')) {
		add_action( 'wp_loaded', 'playhockey_load_custom_options' );
		function playhockey_load_custom_options() {
			if (!playhockey_storage_get('options_reloaded')) {
				playhockey_storage_set('options_reloaded', true);
				playhockey_load_theme_options();
			}
		}
	}
}

// Load current values for each customizable option
if ( !function_exists('playhockey_load_theme_options') ) {
	function playhockey_load_theme_options() {
		$options = playhockey_storage_get('options');
		$reset = (int) get_theme_mod('reset_options', 0);
		foreach ($options as $k=>$v) {
			if (isset($v['std'])) {
				if (strpos($v['std'], '$playhockey_')!==false) {
					$func = substr($v['std'], 1);
					if (function_exists($func)) {
						$v['std'] = $func($k);
					}
				}
				$value = $v['std'];
				if (!$reset) {
					if (isset($_GET[$k]))
						$value = sanitize_text_field($_GET[$k]);
					else {
						$tmp = get_theme_mod($k, -987654321);
						if ($tmp != -987654321) $value = $tmp;
					}
				}
				playhockey_storage_set_array2('options', $k, 'val', $value);
				if ($reset) remove_theme_mod($k);
			}
		}
		if ($reset) {
			// Unset reset flag
			set_theme_mod('reset_options', 0);
			// Regenerate CSS with default colors and fonts
			playhockey_customizer_save_css();
		} else {
			do_action('playhockey_action_load_options');
		}
	}
}

// Override options with stored page/post meta
if ( !function_exists('playhockey_override_theme_options') ) {
	add_action( 'wp', 'playhockey_override_theme_options', 1 );
	function playhockey_override_theme_options($query=null) {
		if (is_page_template('blog.php')) {
			playhockey_storage_set('blog_archive', true);
			playhockey_storage_set('blog_template', get_the_ID());
		}
		playhockey_storage_set('blog_mode', playhockey_detect_blog_mode());
		if (is_singular()) {
			playhockey_storage_set('options_meta', get_post_meta(get_the_ID(), 'playhockey_options', true));
		}
	}
}


// Return customizable option value
if (!function_exists('playhockey_get_theme_option')) {
	function playhockey_get_theme_option($name, $defa='', $strict_mode=false, $post_id=0) {
		$rez = $defa;
		$from_post_meta = false;
		if ($post_id > 0) {
			if (!playhockey_storage_isset('post_options_meta', $post_id))
				playhockey_storage_set_array('post_options_meta', $post_id, get_post_meta($post_id, 'playhockey_options', true));
			if (playhockey_storage_isset('post_options_meta', $post_id, $name)) {
				$tmp = playhockey_storage_get_array('post_options_meta', $post_id, $name);
				if (!playhockey_is_inherit($tmp)) {
					$rez = $tmp;
					$from_post_meta = true;
				}
			}
		}

		if (!$from_post_meta && playhockey_storage_isset('options')) {
			if ( !playhockey_storage_isset('options', $name) ) {
				$rez = $tmp = '_not_exists_';
				if (function_exists('trx_addons_get_option'))
					$rez = trx_addons_get_option($name, $tmp, false);
				if ($rez === $tmp) {
					if ($strict_mode) {
						$s = debug_backtrace();
						$s = array_shift($s);
						echo '<pre>' . sprintf(esc_html__('Undefined option "%s" called from:', 'playhockey'), $name);
						if (function_exists('dco')) dco($s);
						else print_r($s);
						echo '</pre>';
						wp_die();
					} else
						$rez = $defa;
				}
			} else {
				$blog_mode = playhockey_storage_get('blog_mode');
				// Override option from GET or POST for current blog mode
				if (!empty($blog_mode) && isset($_REQUEST[$name . '_' . $blog_mode])) {
					$rez = sanitize_text_field($_REQUEST[$name . '_' . $blog_mode]);
				// Override option from GET
				} else if (isset($_REQUEST[$name])) {
					$rez = sanitize_text_field($_REQUEST[$name]);
				// Override option from current page settings (if exists)
				} else if (playhockey_storage_isset('options_meta', $name) && !playhockey_is_inherit(playhockey_storage_get_array('options_meta', $name))) {
					$rez = playhockey_storage_get_array('options_meta', $name);
				// Override option from current blog mode settings: 'home', 'search', 'page', 'post', 'blog', etc. (if exists)
				} else if (!empty($blog_mode) && playhockey_storage_isset('options', $name . '_' . $blog_mode, 'val') && !playhockey_is_inherit(playhockey_storage_get_array('options', $name . '_' . $blog_mode, 'val'))) {
					$rez = playhockey_storage_get_array('options', $name . '_' . $blog_mode, 'val');
				// Get saved option value
				} else if (playhockey_storage_isset('options', $name, 'val')) {
					$rez = playhockey_storage_get_array('options', $name, 'val');
				// Get ThemeREX Addons option value
				} else if (function_exists('trx_addons_get_option')) {
					$rez = trx_addons_get_option($name, $defa, false);
				}
			}
		}
		return $rez;
	}
}


// Check if customizable option exists
if (!function_exists('playhockey_check_theme_option')) {
	function playhockey_check_theme_option($name) {
		return playhockey_storage_isset('options', $name);
	}
}

// Get dependencies list from the Theme Options
if ( !function_exists('playhockey_get_theme_dependencies') ) {
	function playhockey_get_theme_dependencies() {
		$options = playhockey_storage_get('options');
		$depends = array();
		foreach ($options as $k=>$v) {
			if (isset($v['dependency'])) 
				$depends[$k] = $v['dependency'];
		}
		return $depends;
	}
}

// Return internal theme setting value
if (!function_exists('playhockey_get_theme_setting')) {
	function playhockey_get_theme_setting($name) {
		return playhockey_storage_isset('settings', $name) ? playhockey_storage_get_array('settings', $name) : false;
	}
}


// Set theme setting
if ( !function_exists( 'playhockey_set_theme_setting' ) ) {
	function playhockey_set_theme_setting($option_name, $value) {
		if (playhockey_storage_isset('settings', $option_name))
			playhockey_storage_set_array('settings', $option_name, $value);
	}
}
?>